/**
 * Project: Max'Com: an oral communication software solution that provides
 * pre-recorded sound <-> daylife image / word associations. Autistic people
 * or persons with communication problems are to be the main users. The
 * content is sorted by categories that helps users to express themselves
 * according to the context.
 * File name: Category.java
 * Description: this class represents a category.
 * 
 * @author Telecom Lille1 on 2010-11-23
 * @copyright 2010 Max'Com team. All rights reserved.
 * @version $Id: code-gpl-license.txt,v 1.2 2004/05/04 13:19:30 garry Exp $
 * 
 * @see The GNU Public License (GPL) version 3 or higher
 *
 * 
 * Max'Com is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 3 of the License, or 
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License 
 * for more details.
 * 
 * You should have received a copy of the GNU General Public License along 
 * with this program; if not, write to the Free Software Foundation, Inc., 
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

package maxcom.mobile;

public class Category implements Comparable<Category> {

	protected int id;
	protected String name;
	protected String image;
	protected int parentId;
	protected int rank;

	public Category(int id, String name, String image, int parent, int rank) {
		this.id = id;
		this.name = name;
		this.image = image;
		this.parentId = parent;
		this.rank = rank;
	}

	public int getId() {
		return id;
	}

	public String getName() {
		return name;
	}

	public String getImage() {
		return image;
	}

	public int getParentId() {
		return parentId;
	}

	public int getRank() {
		return rank;
	}

	public void setId(int id) {
		if (id != DataFieldDictionary.VOID_INT)
			this.id = id;
	}

	public void setName(String name) {
		if (name != DataFieldDictionary.VOID_STR)
			this.name = name;
	}

	public void setImage(String image) {
		if (image != DataFieldDictionary.VOID_STR)
			this.image = image;
	}

	public void setParentId(int parentId) {
		if (parentId != DataFieldDictionary.VOID_INT)
			this.parentId = parentId;
	}

	public void setRank(int rank) {
		if (rank != DataFieldDictionary.VOID_INT)
		this.rank = rank;
	}

	public int compareTo(Category another) {
		int nb1 = (another).getRank();
		int nb2 = this.rank;
		if (nb1 > nb2)
			return -1;
		else if (nb1 == nb2)
			return 0;
		else
			return 1;
	}

	@Override
	public String toString() {
		return "Category<" + getId() + ", " + getName() + ">";
	}

}
