/**
 * Project: Max'Com: an oral communication software solution that provides
 * pre-recorded sound <-> daylife image / word associations. Autistic people
 * or persons with communication problems are to be the main users. The
 * content is sorted by categories that helps users to express themselves
 * according to the context.
 * File name: ConfigurationForm.java
 * Description: this class is used to save and modify the configuration.
 * 
 * @author Telecom Lille1, ISEN Lille on 2010-11-23
 * @copyright 2010 Max'Com team. All rights reserved.
 * @version $Id: code-gpl-license.txt,v 1.2 2004/05/04 13:19:30 garry Exp $
 * 
 * @see The GNU Public License (GPL) version 3 or higher
 *
 * 
 * Max'Com is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 3 of the License, or 
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License 
 * for more details.
 * 
 * You should have received a copy of the GNU General Public License along 
 * with this program; if not, write to the Free Software Foundation, Inc., 
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

package maxcom.mobile;

import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.Date;

import maxcom.mobile.R;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.CompoundButton;
import android.widget.EditText;
import android.widget.Toast;
import android.widget.ToggleButton;
import android.widget.CompoundButton.OnCheckedChangeListener;

public class ConfigurationForm extends Activity {

	public static final String tag = ConfigurationForm.class.getName();

	protected Button ok;
	protected EditText serverUriEdit;
	protected EditText loginEdit;
	protected EditText loginPasswordEdit;
	protected EditText appPasswordEdit;
	protected ToggleButton toggleRestart;
	protected boolean firstLaunch = false;

	@Override
		protected void onCreate(Bundle savedInstanceState) {
			super.onCreate(savedInstanceState);
			setContentView(R.layout.parameters_dialog);
			Bundle extra = getIntent().getExtras();
			// recupere l'information d'un premier lancement
			if (extra!=null){
				firstLaunch = extra.getBoolean("firstLaunch");
			}
			ok = (Button) findViewById(R.id.BoutonOkEnregistrement);
			serverUriEdit = (EditText) findViewById(R.id.server_url);
			loginEdit = (EditText) findViewById(R.id.texte_login);
			loginPasswordEdit = (EditText) findViewById(R.id.texte_password);
			appPasswordEdit = (EditText) findViewById(R.id.password_appli);
			toggleRestart = (ToggleButton) findViewById(R.id.toggleRestart);
			
			// si ce n'est pas un premier lancement, on affiche les info d'identification
			if(!firstLaunch){
				ConfigurationData.load(getApplicationContext());
				serverUriEdit.setText(ConfigurationData.getServerUri().toString());
				loginEdit.setText(ConfigurationData.getLogin());
				loginPasswordEdit.setText(ConfigurationData.getLoginPassword());
				appPasswordEdit.setText(ConfigurationData.getAppPassword());
				if (ConfigurationData.mustRestartApp()) {
					if (!toggleRestart.isChecked()) toggleRestart.toggle();
				}
			}else{
				ok.setText("Enregistrer");
			}
			ok.setOnClickListener(new OnClickListener() {
				public void onClick(View v) {
					end();
				}
			});
			toggleRestart.setOnCheckedChangeListener(new OnCheckedChangeListener() {	
				public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
					ConfigurationData.switchRestartApp();
				}
			});
		}

	/**
	 * Verification du remplissage des champs.
	 */
	private void end() {
		// on recupere les donnees fournies pas l'utilisateur

		String serverUri = serverUriEdit.getText().toString();
		int iServer = serverUri.length();

		String login = loginEdit.getText().toString();
		int iLogin = login.length();

		String loginPassword = loginPasswordEdit.getText().toString();
		int iPass = loginPassword.length();

		String appPassword = appPasswordEdit.getText().toString();
		int iPassAppli = appPassword.length();


		// on test si l'utilisateur a bien rempli les champs
		if (iServer > 0 && iLogin > 0 && iPass > 0 && iPassAppli > 0 ) {
			ConfigurationData.setServerUri(serverUri);
			ConfigurationData.setLogin(login);
			ConfigurationData.setLoginPassword(loginPassword);
			ConfigurationData.setAppPassword(appPassword);

			// si c'est un premier lancement, on lance le splashscreen
			if(firstLaunch == true){
				ConfigurationData.resetUpdateDate();
				ConfigurationData.save(getApplicationContext());				
				finish();

				Intent intent = new Intent(this, SplashScreenActivity.class);
				startActivity(intent);
			}else{  // sinon on ecrit dans le fichier de stockage des infos
				ConfigurationData.save(getApplicationContext());
				finish();
			}

		} else { // si les champs ne sont pas correctement renseignes
			Toast.makeText(this,
					"Veuillez remplir correctement tous les champs",
					Toast.LENGTH_SHORT).show();
		}

	}

}
