/**
 * Project: Max'Com: an oral communication software solution that provides
 * pre-recorded sound <-> daylife image / word associations. Autistic people
 * or persons with communication problems are to be the main users. The
 * content is sorted by categories that helps users to express themselves
 * according to the context.
 * File name: CategoryCmdImageUtil.java
 * Description: Abstract class that factorizes behaviour for downloading image
 * 
 * @author Telecom Lille1 on 2010-11-23
 * @copyright 2010 Max'Com team. All rights reserved.
 * @version $Id: code-gpl-license.txt,v 1.2 2004/05/04 13:19:30 garry Exp $
 * 
 * @see The GNU Public License (GPL) version 3 or higher
 *
 * 
 * Max'Com is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 3 of the License, or 
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License 
 * for more details.
 * 
 * You should have received a copy of the GNU General Public License along 
 * with this program; if not, write to the Free Software Foundation, Inc., 
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

package maxcom.mobile;

import java.io.File;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.URL;

import android.net.Uri;
import android.util.Log;

public abstract class DatabaseCmdImageUtil {

	public static final String tag = DatabaseCmdImageUtil.class.getName();

	public abstract String getCmdPart();

	protected String getDownloadImageURL(String image)
			throws MalformedURLException {
		Uri serverUri = ConfigurationData.getServerUri();
		String cmd = getCmdPart();
		// String cmd = isCategoryCmd() ? "category_image" : "sheet_image";
		String synchroPart = MaxCom.getSynchroPart();
		String action = "/" + cmd + "/" + image;
		return Uri.withAppendedPath(serverUri, synchroPart + action).toString();
	}

	public boolean downloadImage(String image) {
		boolean downloaded = false;

		try {
			// set the download URL, a url that points to a file on the
			// internet
			// this is the file to be downloaded

			String imageURL = getDownloadImageURL(image);
			URL url = new URL(imageURL);
			if (BuildConfig.DEBUG)
				Log.i(tag, url.toString());

			// create the new connection
			HttpURLConnection urlConnection = (HttpURLConnection) url
					.openConnection();

			// set up some things on the connection
			urlConnection.setRequestMethod("GET");
			urlConnection.setDoOutput(true);
			// and connect!
			urlConnection.connect();

			// this will be used in reading the data from the internet
			InputStream inputStream = urlConnection.getInputStream();

			// this is the total size of the file
			int totalSize = urlConnection.getContentLength();
			// variable to store total downloaded bytes
			int downloadedSize = 0;

			if (totalSize != 0) {

				// create a buffer...
				byte[] buffer = new byte[1024];
				int bufferLength = 0; // used to store a temporary size of
				// the buffer

				// create a new file for storing image
				File file = new File(MaxCom.getImagesDirectory(), image);
				file.createNewFile();

				// this will be used to write the downloaded data into the
				// file we created
				FileOutputStream fileOutput = new FileOutputStream(file);

				// now, read through the input buffer and write the contents
				// to the file
				while ((bufferLength = inputStream.read(buffer)) > 0) {
					// add the data in the buffer to the file in the file
					// output stream (the file on the sd card
					fileOutput.write(buffer, 0, bufferLength);
					// add up the size so we know how much is downloaded
					downloadedSize += bufferLength;
					// this is where you would do something to report the
					// prgress, like this maybe
				}
				if ((downloadedSize > 0)
						&& (totalSize == -1 || totalSize == downloadedSize)) {
					downloaded = true;
				}

				if (BuildConfig.DEBUG)
					Log.i(tag, "Progress: downloadedSize:" + downloadedSize
							+ "totalSize:" + totalSize);
				// close the output stream when done
				fileOutput.close();

				if (BuildConfig.DEBUG)
					Log.i(tag, "file path:" + file.getPath());
			}
			// catch some possible errors...
		} catch (Exception e) {
			if (BuildConfig.DEBUG)
				Log.e(tag, e.toString());
		}

		return downloaded;
	}

	public void removeImageFromDirectory(String image) {
		if (!image.equals("")) {
			File file = new File(MaxCom.getImagesDirectory(), image);
			file.delete();
		}

	}
}