/**
 * Project: Max'Com: an oral communication software solution that provides
 * pre-recorded sound <-> daylife image / word associations. Autistic people
 * or persons with communication problems are to be the main users. The
 * content is sorted by categories that helps users to express themselves
 * according to the context.
 * File name: DisplaySheetActivity.java
 * Description: this class shows a sheet using "sheet.xml"'s layout.
 * 
 * @author Telecom Lille1, ISEN Lille on 2010-11-23
 * @copyright 2010 Max'Com team. All rights reserved.
 * @version $Id: code-gpl-license.txt,v 1.2 2004/05/04 13:19:30 garry Exp $
 * 
 * @see The GNU Public License (GPL) version 3 or higher
 *
 * 
 * Max'Com is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 3 of the License, or 
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License 
 * for more details.
 * 
 * You should have received a copy of the GNU General Public License along 
 * with this program; if not, write to the Free Software Foundation, Inc., 
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

package maxcom.mobile;

import java.util.LinkedList;
import java.util.List;
import java.util.Locale;

import android.app.Activity;
import android.content.Intent;
import android.graphics.Bitmap;
import android.os.Bundle;
import android.speech.tts.TextToSpeech;
import android.util.Log;
import android.view.View;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.Button;
import android.widget.Gallery;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.Toast;

public class DisplaySheetActivity extends Activity implements
		TextToSpeech.OnInitListener {

	protected static final String tag = DisplaySheetActivity.class.getName();

	// sheet related data
	protected Sheet currentSheet;
	protected List<Sheet> similarSheets;
	protected List<String> similarImages;

	protected DatabaseHelper dbHelper;

	// widgets
	protected int imageSize;
	protected Gallery gallery;
	protected ImageView viewImageSheet;
	protected TextView textSheet;
	protected GalleryImageAdapter imageAdapter;
	protected LinearLayout layoutSheet;
	protected Button back;

	protected static int MY_DATA_CHECK_CODE = 0;
	protected static int MAX_CLICK = 3;

	protected int nbClick;
	protected TextToSpeech mTts;
	protected boolean ttsOK;

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.sheet);

		dbHelper = MaxCom.getDatabaseHelper();

		similarSheets = new LinkedList<Sheet>();
		similarImages = new LinkedList<String>();

		Bundle extra = getIntent().getExtras();
		if (extra != null) {
			currentSheet = (Sheet) extra.getSerializable("sheet");
			imageSize = extra.getInt("imageSize");
		} else {
			Toast.makeText(getBaseContext(), getText(R.string.strErreurFiche),
					Toast.LENGTH_LONG).show();
			finish();
			return;
		}

		retrieveSimilarSheets();
		initTextToSpeech();
		initWidgets();
		updated();
	}

	/**
	 * Initialize text to speech service
	 */
	protected void initTextToSpeech() {
		// Instanciation de l'objet mTts avec l'objet courant comme ecouteur
		ttsOK = false;
		mTts = new TextToSpeech(this, this);
	}

	/**
	 * Play the current sheet's name using the text to speech service
	 */
	protected void speak() {
		if (ttsOK)
			mTts.speak(currentSheet.getName(), TextToSpeech.QUEUE_FLUSH, null);
	}

	/**
	 * Initialize widgets
	 */
	protected void initWidgets() {
		layoutSheet = (LinearLayout) findViewById(R.id.LayoutSheet);
		viewImageSheet = (ImageView) findViewById(R.id.SheetImage);
		textSheet = (TextView) findViewById(R.id.TextSheet);
		back = (Button) findViewById(R.id.Retour);

		layoutSheet.setOnClickListener(new View.OnClickListener() {
			public void onClick(View view) {
				if (nbClick < MAX_CLICK) {
					speak();
					// increment nb of click for current sheet
					nbClick += 1;
					currentSheet.incrNbClicks();
				}
			}
		});
		back.setOnClickListener(new View.OnClickListener() {
			public void onClick(View v) {
				finish();
			}
		});

		// Update imageGallery
		gallery = (Gallery) findViewById(R.id.sheet_gallery);
		imageAdapter = new GalleryImageAdapter(this, imageSize, similarImages);
		gallery.setAdapter(imageAdapter);
		gallery.setOnItemClickListener(new OnItemClickListener() {
			public void onItemClick(AdapterView<?> parent, View v,
					int position, long id) {
				
				// save nb of click in database
				dbHelper.open();
				if (BuildConfig.DEBUG)
					Log.i(tag, "Updating nb of clicks for:" + currentSheet); 
				dbHelper.updateNbClicksSheet(currentSheet);
				dbHelper.close();

				// change current sheet
				nbClick = 0;
				currentSheet = similarSheets.get(position);
				retrieveSimilarSheets();
				updated();
			}
		});

	}

	/**
	 * Retrieve sheets that have similar terms to current sheet
	 */
	protected void retrieveSimilarSheets() {
		SheetTermClassifier classifier = MaxCom.getTermClassifier();
		similarSheets.clear();
		similarSheets.addAll(classifier.getSimilarSheets(currentSheet));

		similarImages.clear();
		for (Sheet sh : similarSheets) {
			similarImages.add(sh.getImage());
		}
	}

	/**
	 * Update the widgets after a new selection
	 */
	protected void updated() {
		nbClick = 1;

		// affichage image et nom
		Bitmap bitmap = MaxCom.getImageBitmap(currentSheet.getImage());
		if (bitmap != null)
			viewImageSheet.setImageBitmap(bitmap);
		textSheet.setText(currentSheet.getName());

		imageAdapter.notifyDataSetChanged();

		speak();

	}

	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		super.onActivityResult(requestCode, resultCode, data);
		if (requestCode == MY_DATA_CHECK_CODE) {
			if (requestCode == TextToSpeech.Engine.CHECK_VOICE_DATA_PASS) {
				mTts = new TextToSpeech(this, this);
			} else {
				Intent installIntent = new Intent();
				installIntent
						.setAction(TextToSpeech.Engine.ACTION_INSTALL_TTS_DATA);
				startActivityForResult(installIntent, MY_DATA_CHECK_CODE);
			}
		}
	}

	@Override
	public void onDestroy() {
		// Don't forget to shutdown!
		if (mTts != null) {
			mTts.stop();
			mTts.shutdown();
		}

		super.onDestroy();
	}

	// Implements TextToSpeech.OnInitListener.
	public void onInit(int status) {
		// status can be either TextToSpeech.SUCCESS or TextToSpeech.ERROR.
		if (status == TextToSpeech.SUCCESS) {
			// le choix de la langue ici francais
			int result = mTts.setLanguage(Locale.FRANCE);
			// verification ici si cette langue est supporte par le terminal et
			// si elle existe
			if (result == TextToSpeech.LANG_MISSING_DATA
					|| result == TextToSpeech.LANG_NOT_SUPPORTED) {

				// renvoi une erreur sur la console logcat.
				if (BuildConfig.DEBUG)
					Log.e("tts", "LANG_MISSING_DATA");
			} else {
				ttsOK = true;
				speak();
			}
		}
	}
}
