/**
 * Project: Max'Com: an oral communication software solution that provides
 * pre-recorded sound <-> daylife image / word associations. Autistic people
 * or persons with communication problems are to be the main users. The
 * content is sorted by categories that helps users to express themselves
 * according to the context.
 * File name: ImageAdapter2.java
 * Description: this class manage the images displayed in MainScreen grid view
 * 
 * @author Telecom Lille1, ISEN Lille on 2010-11-23
 * @copyright 2010 Max'Com team. All rights reserved.
 * @version $Id: code-gpl-license.txt,v 1.2 2004/05/04 13:19:30 garry Exp $
 * 
 * @see The GNU Public License (GPL) version 3 or higher
 *
 * 
 * Max'Com is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 3 of the License, or 
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License 
 * for more details.
 * 
 * You should have received a copy of the GNU General Public License along 
 * with this program; if not, write to the Free Software Foundation, Inc., 
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

package maxcom.mobile;

import java.util.LinkedList;
import java.util.List;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.Paint.Style;
import android.graphics.Rect;
import android.graphics.RectF;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.GridView;
import android.widget.ImageView;

public class GridViewImageAdapter extends BaseAdapter {
	protected Context mContext;
	protected List<GridViewElement> elements;
	protected int largeurImage;

	public GridViewImageAdapter(Context c, List<GridViewElement> gridViewElements,
			int largeurImage) {
		mContext = c;
		this.largeurImage = largeurImage;
		elements = gridViewElements;
	}

	public int getCount() {
		return elements.size();
	}

	public Object getItem(int position) {
		return null;
	}

	public long getItemId(int position) {
		return 0;
	}

	public View getView(int position, View convertView, ViewGroup parent) {
		ImageView imageView;
		if (convertView == null) {
			imageView = new ImageView(mContext);
			imageView.setLayoutParams(new GridView.LayoutParams(largeurImage,
					largeurImage));
			imageView.setScaleType(ImageView.ScaleType.CENTER_CROP);
			imageView.setPadding(8, 8, 8, 8);
		} else {
			imageView = (ImageView) convertView;
		}
		GridViewElement element = elements.get(position);
		String imageName = element.getImagePath();

		Bitmap source = MaxCom.getImageBitmap(imageName);
		if (element.isCategoryType()) {
			int fHeight = source.getHeight();
			int fWidth = source.getWidth();
			Bitmap dest = Bitmap.createBitmap(fWidth, fHeight, source.getConfig());
			RectF targetRect = new RectF(0, 0, fWidth, fHeight);
			Canvas canvas = new Canvas(dest);
			Paint paint = new Paint();
			paint.setColor(Color.BLUE);
			paint.setStrokeWidth(20);
			paint.setStyle(Style.STROKE);
		    canvas.drawBitmap(source, null, targetRect, null);
			canvas.drawRect(0, 0, fWidth, fHeight, paint);
			imageView.setImageBitmap(dest);
		} 
		else {
			imageView.setImageBitmap(source);
		}

		return imageView;
	}
	

}
