/**
 * Project: Max'Com: an oral communication software solution that provides
 * pre-recorded sound <-> daylife image / word associations. Autistic people
 * or persons with communication problems are to be the main users. The
 * content is sorted by categories that helps users to express themselves
 * according to the context.
 * File name: LogFormatter.java
 * Description: This class customizes the formatting of log records
 * 
 * @author Telecom Lille1, ISEN Lille on 2010-11-23
 * @copyright 2010 Max'Com team. All rights reserved.
 * @version $Id: code-gpl-license.txt,v 1.2 2004/05/04 13:19:30 garry Exp $
 * 
 * @see The GNU Public License (GPL) version 3 or higher
 *
 * 
 * Max'Com is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 3 of the License, or 
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License 
 * for more details.
 * 
 * You should have received a copy of the GNU General Public License along 
 * with this program; if not, write to the Free Software Foundation, Inc., 
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

package maxcom.mobile;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.text.DateFormat;
import java.util.Date;
import java.util.logging.Formatter;
import java.util.logging.LogRecord;

public class LogFormatter extends Formatter
{
	
	static final String LocalTag = LogFormatter.class.getName();
	protected static final int maxFrames = 5; 
    
    protected DateFormat dateFormat;
    static final String lineSep = System.getProperty("line.separator");

    @Override
    public String format(LogRecord record)
    {
      StringBuffer buf = new StringBuffer();
  
      if (dateFormat == null)
        dateFormat = DateFormat.getDateTimeInstance();
  
      buf.append(dateFormat.format(new Date(record.getMillis())));
      buf.append(' ');
      buf.append(record.getSourceClassName());
      buf.append(' ');
      buf.append(record.getSourceMethodName());
      buf.append(lineSep);
  
      buf.append(record.getLevel());
      buf.append(": ");
      buf.append(formatMessage(record));
  
      buf.append(lineSep);
  
      Throwable throwable = record.getThrown();
      if (throwable != null) {
          StringWriter strWriter = new StringWriter();
          PrintWriter prtWriter = new PrintWriter(strWriter);
          
          prtWriter.println(throwable);
          StackTraceElement[] frames = throwable.getStackTrace();
          if (frames != null)
          {
        	  int l = frames.length; 
        	  if (l >= maxFrames) l = maxFrames; 
        	  for (int i = 0; i < l; i++)
        		  prtWriter.println("\tat " + frames[i]);
          }
          
          buf.append(strWriter.toString());
      }
      buf.append("---------------------");
      buf.append(lineSep);
      
      return buf.toString();
    }
  
    
    protected void writeJSON (StringWriter writer, String name, String value)
    {
        writer.append("\""+name+"\": "+"\""+value+"\"");
    }
}