/**
 * Project: Max'Com: an oral communication software solution that provides
 * pre-recorded sound <-> daylife image / word associations. Autistic people
 * or persons with communication problems are to be the main users. The
 * content is sorted by categories that helps users to express themselves
 * according to the context.
 * File name: LoggingForm.java
 * Description: This class shows a screen using "logging.xml"'s layout.
 * 
 * @author Telecom Lille1, ISEN Lille on 2010-11-23
 * @copyright 2010 Max'Com team. All rights reserved.
 * @version $Id: code-gpl-license.txt,v 1.2 2004/05/04 13:19:30 garry Exp $
 * 
 * @see The GNU Public License (GPL) version 3 or higher
 *
 * 
 * Max'Com is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 3 of the License, or 
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License 
 * for more details.
 * 
 * You should have received a copy of the GNU General Public License along 
 * with this program; if not, write to the Free Software Foundation, Inc., 
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

package maxcom.mobile;

import java.io.File;
import java.io.FileReader;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;

import android.app.Activity;
import android.os.Bundle;
import android.view.View;
import android.widget.EditText;
import android.widget.RadioButton;
import android.widget.RadioGroup;

public class LoggingForm extends Activity  {

	protected static final String LocalTag = LoggingForm.class.getName();
	
	protected EditText journalEdit; 
	protected RadioButton radioSynchro;
	protected RadioButton radioError;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
        setContentView(R.layout.log_dialog);
        
        // mode debug ?
        boolean debugMode = false;
        Bundle extra = getIntent().getExtras();
		if (extra != null) {
			debugMode = extra.getBoolean("debug");
		}
        
        EditText lastUpdateEdit = (EditText) findViewById(R.id.last_update);
        Date date = ConfigurationData.getDateLastUpdate();
        String dateLastUpdate = new SimpleDateFormat("yyyy-MM-dd/HH:mm:ss", Locale.US).format(date);
        
        lastUpdateEdit.setText(dateLastUpdate);

        journalEdit = (EditText) findViewById(R.id.journalview);
             
        RadioGroup radioGroup = (RadioGroup) findViewById(R.id.radioGroup1);
        radioGroup.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
			public void onCheckedChanged(RadioGroup group, int checkedId) {
				fillJournal();
			}
		});
             
        radioSynchro = (RadioButton) findViewById(R.id.radioSynchro);
        radioError = (RadioButton) findViewById(R.id.radioError);
        if (!debugMode) {
        	radioError.setVisibility(View.INVISIBLE);
        }
        
        fillJournal();
   }
	
		
	protected void fillJournal() {
		if (radioSynchro.isChecked()) {
			fillWithSynchroStats();
		} 
		else {
			fillWithErrors();
		}
	}

	/**
	 * Fill the TextView with synchronization statistics
	 */
	protected void fillWithSynchroStats() {
		DatabaseSynchronizer dbSynchronizer = MaxCom.getDatabaseSynchonizer();
        StringBuffer buffer = new StringBuffer();
        
        buffer.append(String.format("Nb insertions: %d\n", dbSynchronizer.getNbInsert()));
        buffer.append(String.format("Nb mises a jour: %d\n", dbSynchronizer.getNbUpdate()));
        buffer.append(String.format("Nb suppressions: %d\n", dbSynchronizer.getNbDelete()));
        buffer.append("--------\n");
        
        buffer.append(String.format("Nb erreurs insertion: %d\n", dbSynchronizer.getNbInsertErrors()));
        buffer.append(String.format("Nb erreurs maj: %d\n", dbSynchronizer.getNbUpdateErrors()));
        buffer.append(String.format("Nb erreurs suppressions: %d\n", dbSynchronizer.getNbDeleteErrors()));
        buffer.append("--------\n");
        
        for (String msg: dbSynchronizer.getMessageErrors()) {
        	buffer.append(msg + "\n\n");
        }
        journalEdit.setText(buffer.toString());
	}
	
	/**
	 * Fill the TextView with errors retrieved from logging file
	 */
	protected void fillWithErrors() {
		StringBuffer buffer = new StringBuffer();
		File file = new File(getFilesDir(), MaxCom.logFileName);
	    
		try {
			// Reading the content of the file
        	FileReader reader = new FileReader(file);
			boolean eof = false; 
			do {
				int rc = reader.read();
				if (rc == -1) {
					eof = true;
				} 
				else {
					buffer.append((char) rc);
				}
			} while(!eof);
			reader.close();
		} 
	    catch(Exception e) {
	        e.printStackTrace();
	        buffer.append("Error when opening log file:" + e.getMessage());
	    }
	    journalEdit.setText(buffer.toString());
	    
	}
}
