/**
 * Project: Max'Com: an oral communication software solution that provides
 * pre-recorded sound <-> daylife image / word associations. Autistic people
 * or persons with communication problems are to be the main users. The
 * content is sorted by categories that helps users to express themselves
 * according to the context.
 * File name: MainScreen.java
 * Description: Application Class for shared objects and global utility functions
 * 
 * 
 * @author Telecom Lille1, ISEN Lille on 2010-11-23
 * @copyright 2010 Max'Com team. All rights reserved.
 * @version $Id: code-gpl-license.txt,v 1.2 2004/05/04 13:19:30 garry Exp $
 * 
 * @see The GNU Public License (GPL) version 3 or higher
 *
 * 
 * Max'Com is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 3 of the License, or 
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License 
 * for more details.
 * 
 * You should have received a copy of the GNU General Public License along 
 * with this program; if not, write to the Free Software Foundation, Inc., 
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

package maxcom.mobile;

import java.util.ArrayList;
import java.util.Collections;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

import android.app.Activity;
import android.app.Dialog;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.text.Editable;
import android.text.TextWatcher;
import android.util.DisplayMetrics;
import android.util.Log;
import android.view.Display;
import android.view.KeyEvent;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.Surface;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Gallery;
import android.widget.GridView;
import android.widget.ListAdapter;
import android.widget.TextView;

public class MainScreenActivity extends Activity {

	public static final String tag = MainScreenActivity.class.getName();

	protected static final String debugPassword = "8080";

	protected Gallery favoritesGallery;
	protected Gallery categoriesGallery;
	protected GridView gridview;
	protected DatabaseHelper dbHelper;
	protected int imageSize;
	protected List<String> favoriteImages;
	protected Map<String, Integer> categoryImages;
	protected Sheet sheet;
	protected List<Category> categories;
	protected int selectedCategoryPos;

	protected static ArrayList<GridViewElement> gridViewElements;
	protected TextView categoryTextView;

	protected boolean closingEnabled = false;
	protected boolean debugMode;

	protected final static int TILES = 5;
	protected final static int HIGH_DEFINITION = 1600;

	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);
		closingEnabled = false;

		fetchDataFromDB();

		// Activity creation after orientation change - restore previous
		// selected category
		if (savedInstanceState != null)
			selectedCategoryPos = savedInstanceState
					.getInt("selectedCategoryPos");
		else
			selectedCategoryPos = 0;

		computeImageSize();
		setupWidgets();
	}

	protected void setupWidgets() {
		// Affichage des categories dans la gallerie du haut
		categoriesGallery = (Gallery) findViewById(R.id.gallerieHaut);
		final List<String> _categoryImages = new LinkedList<String>(
				categoryImages.keySet());

		categoriesGallery.setAdapter(new GalleryImageAdapter(this, imageSize,
				_categoryImages));
		// implementation onClick pour afficher les images de la categorie
		categoriesGallery.setOnItemClickListener(new OnItemClickListener() {
			public void onItemClick(AdapterView<?> parent, View v,
					int position, long id) {
				
				selectedCategoryPos = position;
				int categoryId = getCurrentCategorieId(_categoryImages, selectedCategoryPos);
				updateCategoryTextView(categoryId);
				getGridImagesByCategoryId(
						categoryId,
						parent.getContext());
			}
		});
		categoriesGallery.setSelection(selectedCategoryPos);

		// Affiche du libelle de la categorie dans la TextView
		categoryTextView = (TextView) findViewById(R.id.categoryTextView);
		int categoryId = getCurrentCategorieId(_categoryImages, selectedCategoryPos);
		updateCategoryTextView(categoryId); 

		// Affichage des images dans la gridview
		gridview = (GridView) findViewById(R.id.gridview);
		if (!_categoryImages.isEmpty()) {
			getGridImagesByCategoryId(
					getCurrentCategorieId(_categoryImages, selectedCategoryPos),
					this);
			// implementation onClick pour afficher les fiches de la sous
			// categories ou basculer vers la fiche correspondante
			gridview.setOnItemClickListener(new OnItemClickListener() {
				public void onItemClick(AdapterView<?> parent, View v,
						int position, long id) {
					// selection = type de l'objet clicke, fiche ou sous
					// categorie
					GridViewElement selection = gridViewElements.get(position);
					if (!selection.isCategoryType()) {
						dbHelper.open();
						sheet = dbHelper.getSheetWithImage(gridViewElements
								.get(position).getImagePath());
						dbHelper.close();

						if (sheet != null) {
							startSheetActivity();
						}
					} else {
						dbHelper.open();
						int categoryId = dbHelper
								.getCategoryIdByImagePath(gridViewElements.get(
										position).getImagePath());
						dbHelper.close();
						updateCategoryTextView(categoryId);
						getGridImagesByCategoryId(categoryId,
								parent.getContext());
					}
				}

			});
		}

		// Affichage des favoris dans la gallerie du bas
		favoritesGallery = (Gallery) findViewById(R.id.gallerieBas);
		favoritesGallery.setAdapter(new GalleryImageAdapter(this, imageSize,
				favoriteImages));
		// implementation onClick pour basculer vers la fiche correspondante
		favoritesGallery.setOnItemClickListener(new OnItemClickListener() {
			public void onItemClick(AdapterView<?> parent, View v,
					int position, long id) {

				String favorisSelected = favoriteImages.get(position);

				dbHelper.open();
				sheet = dbHelper.getSheetWithImage(favorisSelected);
				dbHelper.close();
				if (sheet != null) {
					startSheetActivity();
				}
			}
		});
	}

	protected void updateCategoryTextView(int categoryId) {		
		Category category = getCategoryWithId(categoryId);
		categoryTextView.setText(category.getName());
	}
	
	protected Category getCategoryWithId(int categoryId) {
		Category result = null;
		for (Category c: categories) {
			if (c.getId() == categoryId) {
				result = c;
				break;
			}
		}
		return result;
	}
	

	@Override
	protected void onSaveInstanceState(Bundle saveState) {
		super.onSaveInstanceState(saveState);
		saveState.putInt("selectedCategoryPos", selectedCategoryPos);
	}

	/**
	 * Retrieve images for each gallery
	 */
	protected void fetchDataFromDB() {
		dbHelper = MaxCom.getDatabaseHelper();
		dbHelper.open();
		//
		categories = dbHelper.getCategories();
		// recupere la liste des images des categories
		categoryImages = dbHelper.getImageForCategories();

		// recupere les images favorites
		favoriteImages = dbHelper.getImageForFavorites();
		dbHelper.close();
	}

	/**
	 * Compute image size from current orientation
	 * 
	 */
	protected void computeImageSize() {
		Display display;
		display = getWindow().getWindowManager().getDefaultDisplay();

		int rotation = display.getRotation();
		int width = 0;
		int height = 0;
		switch (rotation) {
		case Surface.ROTATION_0:
		case Surface.ROTATION_180:
			width = display.getWidth();
			height = display.getHeight();
			break;
		case Surface.ROTATION_90:
		case Surface.ROTATION_270:
			width = display.getHeight();
			height = display.getWidth();
			break;
		default:
			break;
		}

		int numberOfPixels;
		double factor = 1;
		DisplayMetrics metrics = new DisplayMetrics();
		display.getMetrics(metrics);

		if (width > height) {
			numberOfPixels = metrics.widthPixels;
		} else {
			numberOfPixels = metrics.heightPixels;
		}

		if (numberOfPixels > 1600)
			factor = 2.5;
		else if (numberOfPixels > 1200)
			factor = 2.0;
		else if (numberOfPixels > 900)
			factor = 1.5;
		else
			factor = 1.0;

		imageSize = numberOfPixels / (int) (TILES * factor);

		if (BuildConfig.DEBUG)
			Log.i(tag, "Metrics:" + numberOfPixels + "--" + imageSize + "--"
					+ (TILES * factor));
	}

	protected void startSheetActivity() {
		Intent intent = new Intent(MainScreenActivity.this,
				DisplaySheetActivity.class);

		sheet.incrNbClicks();
		intent.putExtra("sheet", sheet);
		intent.putExtra("imageSize", imageSize);
		closingEnabled = true;
		startActivity(intent);
	}

	/**
	 * Pour recuperer l'ID d'une categorie en fonction de sa position
	 * 
	 * @param _listeImagesCategories
	 *            String[]
	 * @param position
	 *            int
	 * @return l'ID de la categorie
	 */
	private int getCurrentCategorieId(
			final List<String> _listeImagesCategories, int position) {
		return categoryImages.get(_listeImagesCategories.get(position));
	}

	/**
	 * Affiche les images des categories et des fiches dans la gridview
	 * 
	 * @param idCategorie
	 * @param context
	 */
	private void getGridImagesByCategoryId(int idCategorie, Context context) {
		dbHelper.open();
		// recup des sous categories et des fiches de la categorie
		List<Category> alC = dbHelper.getChildCategories(idCategorie);
		List<Sheet> alS = dbHelper.getSheetsByCategoryId(idCategorie);

		dbHelper.close();

		Collections.sort(alS, Collections.reverseOrder());
		// ajout des images dans la gridview
		gridViewElements = new ArrayList<GridViewElement>();
		if (alC != null) {
			for (Category c : alC) {
				gridViewElements.add(new GridViewElement("category", c
						.getImage()));
			}
			for (Sheet s : alS) {
				gridViewElements
						.add(new GridViewElement("sheet", s.getImage()));
			}
		} else {
			for (Sheet s : alS) {
				gridViewElements
						.add(new GridViewElement("sheet", s.getImage()));
			}
		} // creation et affichage de la liste d'image
		ListAdapter listeImages = new GridViewImageAdapter(context,
				gridViewElements, (imageSize * 8 / 10));
		gridview.setAdapter(listeImages);
	}

	/**
	 * Gestion du bouton back pour emp�cher de sortir sans code (version Android
	 * < 2.0)
	 * 
	 * @param idCategorie
	 * @param context
	 */

	@Override
	public boolean onKeyDown(int keyCode, KeyEvent event) {
		if (android.os.Build.VERSION.SDK_INT <= android.os.Build.VERSION_CODES.DONUT
				&& keyCode == KeyEvent.KEYCODE_BACK
				&& event.getRepeatCount() == 0) {
			onBackPressed();
			return true;
		}
		return super.onKeyDown(keyCode, event);
	}

	/**
	 * Gestion du bouton back pour emp�cher de sortir sans code (version Android
	 * >= 2.0)
	 * 
	 * @param idCategorie
	 * @param context
	 */
	@Override
	public void onBackPressed() {
		final Dialog dialog = new Dialog(MainScreenActivity.this);

		debugMode = false;

		// affichage d'un message pour quitter
		dialog.setContentView(R.layout.exit_dialog);
		dialog.setTitle(R.string.quit_message);
		dialog.setCancelable(true);
		// bouton pour annulation
		Button bCancel = (Button) dialog.findViewById(R.id.buttonexit);
		bCancel.setOnClickListener(new OnClickListener() {
			public void onClick(View v) {
				dialog.cancel();
			}
		});
		// bouton pour quitter invisible
		final Button bExit = (Button) dialog.findViewById(R.id.exitconfirm);
		bExit.setVisibility(View.INVISIBLE);
		bExit.setOnClickListener(new OnClickListener() {
			public void onClick(View v) {
				closingEnabled = true;
				finish();
			}
		});
		// editText pour entrer le mot de passe
		EditText champExit = (EditText) dialog.findViewById(R.id.champexit);
		champExit.addTextChangedListener(new TextWatcher() {
			// si l'utilisateur rentre le bon mot de passe, le bouton devient
			// visible
			public void onTextChanged(CharSequence s, int start, int before,
					int count) {
				debugMode = s.toString().equals(debugPassword);
				if (ConfigurationData.matchAppPassword(s.toString())
						|| debugMode) {
					bExit.setVisibility(View.VISIBLE);
				} else {
					bExit.setVisibility(View.INVISIBLE);
				}
			}

			public void beforeTextChanged(CharSequence s, int start, int count,
					int after) {
			}

			public void afterTextChanged(Editable s) {
			}
		});
		dialog.show();
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		MenuInflater inflater = getMenuInflater();
		inflater.inflate(R.menu.main_menu, menu);
		return true;
	}

	/**
	 * Gestion des menus avec boite de dialogue pour fournir le code
	 */
	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		final Dialog dConfirm = new Dialog(this);

		debugMode = false;
		dConfirm.setContentView(R.layout.exit_dialog);

		dConfirm.setCancelable(true);
		Button bCancel = (Button) dConfirm.findViewById(R.id.buttonexit);
		bCancel.setOnClickListener(new OnClickListener() {
			public void onClick(View v) {
				dConfirm.cancel();
			}
		});
		final Button bExit = (Button) dConfirm.findViewById(R.id.exitconfirm);
		bExit.setVisibility(View.INVISIBLE);
		EditText champExit = (EditText) dConfirm.findViewById(R.id.champexit);
		champExit.addTextChangedListener(new TextWatcher() {

			public void onTextChanged(CharSequence s, int start, int before,
					int count) {
				debugMode = s.toString().equals(debugPassword);
				if (ConfigurationData.matchAppPassword(s.toString())
						|| debugMode) {
					bExit.setVisibility(View.VISIBLE);
				} else {
					bExit.setVisibility(View.INVISIBLE);
				}
			}

			public void beforeTextChanged(CharSequence s, int start, int count,
					int after) {
			}

			public void afterTextChanged(Editable s) {
			}
		});

		switch (item.getItemId()) {

		case R.id.refresh:
			dConfirm.setTitle(R.string.refresh_data_message);
			bExit.setOnClickListener(new OnClickListener() {

				public void onClick(View v) {
					finish();
					Intent intent = new Intent(MainScreenActivity.this,
							SplashScreenActivity.class);
					intent.putExtra("update", true);
					closingEnabled = true;
					startActivity(intent);
					dConfirm.cancel();
				}
			});
			dConfirm.show();
			return true;

		case R.id.settings:
			dConfirm.setTitle(R.string.parameters_access_message);
			bExit.setOnClickListener(new OnClickListener() {

				public void onClick(View v) {
					Intent intent2 = new Intent(MainScreenActivity.this,
							ConfigurationForm.class);
					closingEnabled = true;
					startActivity(intent2);
					dConfirm.cancel();
				}
			});
			dConfirm.show();
			return true;

		case R.id.reset:
			dConfirm.setTitle(R.string.reset_data_message);
			bExit.setOnClickListener(new OnClickListener() {
				public void onClick(View v) {
					dbHelper.open();
					dbHelper.removeAllDatas();
					dbHelper.close();
					ConfigurationData.resetUpdateDate();
					ConfigurationData.save(MainScreenActivity.this);
					finish();

					Intent intent = new Intent(MainScreenActivity.this,
							SplashScreenActivity.class);
					intent.putExtra("update", true);
					closingEnabled = true;
					startActivity(intent);
					dConfirm.cancel();
				}
			});
			dConfirm.show();
			return true;

		case R.id.journal:
			dConfirm.setTitle(R.string.journal_access_message);
			bExit.setOnClickListener(new OnClickListener() {

				public void onClick(View v) {
					Intent intent2 = new Intent(MainScreenActivity.this,
							LoggingForm.class);
					intent2.putExtra("debug", debugMode);
					closingEnabled = true;
					startActivity(intent2);
					dConfirm.cancel();
				}
			});
			dConfirm.show();
			return true;

		default:
			return super.onOptionsItemSelected(item);
		}
	}

	@Override
	protected void onStop() {
		super.onStop();

		dbHelper.close();
	}

	@Override
	protected void onStart() {
		super.onRestart();

		dbHelper.open();
		closingEnabled = false;

	}

	@Override
	protected void onDestroy() {
		super.onDestroy();

		if (closingEnabled && ConfigurationData.mustRestartApp()) {
			Intent intent = new Intent(MainScreenActivity.this,
					RestartService.class);
			startService(intent);
		}
		dbHelper.close();
	}

}