/**
 * Project: Max'Com: an oral communication software solution that provides
 * pre-recorded sound <-> daylife image / word associations. Autistic people
 * or persons with communication problems are to be the main users. The
 * content is sorted by categories that helps users to express themselves
 * according to the context.
 * File name: Sheet.java
 * Description: this class represents a sheet.
 * 
 * @author Telecom Lille1 on 2010-11-23
 * @copyright 2010 Max'Com team. All rights reserved.
 * @version $Id: code-gpl-license.txt,v 1.2 2004/05/04 13:19:30 garry Exp $
 * 
 * @see The GNU Public License (GPL) version 3 or higher
 *
 * 
 * Max'Com is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 3 of the License, or 
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License 
 * for more details.
 * 
 * You should have received a copy of the GNU General Public License along 
 * with this program; if not, write to the Free Software Foundation, Inc., 
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

package maxcom.mobile;

import java.io.Serializable;

public class Sheet implements Comparable<Sheet>, Serializable {

	protected int id;
	protected String name;
	protected String image;
	protected int favorite;
	protected int nbClicks;
	protected int nbClicksDelta;
	protected int note;
	protected int status;
	protected String date;
	protected String lastModif;
	protected int authorId;
	protected int categoryId;

	public Sheet(int id, String name, String image, int favorite, int status,
			int nbClicks, int nbClicksDelta, String date, String lastModif,
			int category_id, int author_id, int note) {
		super();
		this.id = id;
		this.name = name;
		this.image = image;
		this.favorite = favorite;
		this.status = status;
		this.nbClicks = nbClicks;
		this.nbClicksDelta = nbClicksDelta;
		this.date = date;
		this.lastModif = lastModif;
		this.categoryId = category_id;
		this.authorId = author_id;
		this.note = note;

	}

	// Accesseurs

	public int getId() {
		return id;
	}

	public String getName() {
		return name;
	}

	public String getImage() {
		return image;
	}

	public void setImage(String image) {
		if (image != null)
			this.image = image;
	}

	public void setName(String name) {
		if (name != null)
			this.name = name;
	}

	public int getFavorite() {
		return favorite;
	}

	public void setFavorite(int favorite) {
		if (favorite != DataFieldDictionary.VOID_INT)
			this.favorite = favorite;
	}

	public int getNbClicks() {
		return nbClicks;
	}

	public int getNbClicksDelta() {
		return nbClicksDelta;
	}

	public void incrNbClicks() {
		this.nbClicks++;
		this.nbClicksDelta++;
	}

	public void resetNbClicksDelta() {
		this.nbClicksDelta = 0;
	}

	public int getNote() {
		return note;
	}

	public void setNote(int note) {
		if (note != DataFieldDictionary.VOID_INT)
			this.note = note;
	}

	public String getDate() {
		return date;
	}

	public void setDate(String date) {
		this.date = date;
	}

	public String getLastModif() {
		return lastModif;
	}

	public void setLastModif(String lastModif) {
		if (lastModif != null)
			this.lastModif = lastModif;
	}

	public int getCategory_id() {
		return categoryId;
	}

	public void setCategoryId(int categoryId) {
		if (categoryId != DataFieldDictionary.VOID_INT)
			this.categoryId = categoryId;
	}

	public int getAuthorId() {
		return authorId;
	}

	public void setAuthorId(int authorId) {
		if (authorId != DataFieldDictionary.VOID_INT)
			this.authorId = authorId;
	}

	public int getStatus() {
		return status;
	}

	public void setStatus(int status) {
		if (status != DataFieldDictionary.VOID_INT)
			this.status = status;
	}

	@Override
	public String toString() {
		return "Sheet<" + getId() + ", " + getName() + ", " + getCategory_id()
				+ "," + hashCode() +">";
	}

	/**
	 * Classement des fiches par note puis par nombre de clics
	 */
	public int compareTo(Sheet another) {
		if (this.note > another.getNote())
			return 1;
		else if (this.note < another.getNote())
			return -1;
		else {
			if (this.nbClicks > another.getNbClicks())
				return 1;
			else if (this.nbClicks < another.getNbClicks())
				return -1;
		}
		return 0;
	}

}
