/**
 * Project: Max'Com: an oral communication software solution that provides
 * pre-recorded sound <-> daylife image / word associations. Autistic people
 * or persons with communication problems are to be the main users. The
 * content is sorted by categories that helps users to express themselves
 * according to the context.
 * File name: SplashScreen.java
 * Description: this class is used to create the database and update it.
 * 
 * @author Telecom Lille1, ISEN Lille on 2010-11-23
 * @copyright 2010 Max'Com team. All rights reserved.
 * @version $Id: code-gpl-license.txt,v 1.2 2004/05/04 13:19:30 garry Exp $
 * 
 * @see The GNU Public License (GPL) version 3 or higher
 *
 * 
 * Max'Com is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 3 of the License, or 
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License 
 * for more details.
 * 
 * You should have received a copy of the GNU General Public License along 
 * with this program; if not, write to the Free Software Foundation, Inc., 
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

package maxcom.mobile;

import java.util.LinkedHashMap;
import java.util.List;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.widget.ProgressBar;
import android.widget.Toast;

/**
 * Class for displaying and managing the splash screen
 * 
 * @author Telecom Lille1, Isen Lille
 * 
 */
public class SplashScreenActivity extends Activity {

	protected static final String LocalTag = SplashScreenActivity.class
			.getName();

	private ProgressBar mProgress;
	public static LinkedHashMap<String, Integer> listeImagesCategories;

	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.splash);

		boolean updateCode = false;
		Bundle extra = getIntent().getExtras();
		if (extra != null) {
			// test if update is required
			updateCode = extra.getBoolean("update");
			if (BuildConfig.DEBUG)
				Log.i(LocalTag, "update:" + updateCode);
		}

		mProgress = (ProgressBar) findViewById(R.id.ProgressBar01);
		mProgress.setIndeterminate(true);
		initThread.start();
	}

	/**
	 * Permet d'ouvrir ou de creer la base de donnees sans geler l'application
	 * puis lance l'activite Configuration ou MaxCom
	 */
	private Thread initThread = new Thread() {
		public void run() {

			// on affiche le formulaire de configuration si elle n'existe pas
			if (!ConfigurationData.isConfigCreated(getApplicationContext())) {
				Intent intent = new Intent(SplashScreenActivity.this,
						ConfigurationForm.class); // affiche le formulaire
				intent.putExtra("firstLaunch", true);
				startActivity(intent);
				finish();
			} else {

				// tentative de mise  jour de la base
				String msg;
				DatabaseSynchronizer dbSynchronizer = MaxCom
						.getDatabaseSynchonizer();
				// synchronisation avec le serveur
				try {
					dbSynchronizer.update();
					// message diffrent selon le rsultat de la synchro
					if (dbSynchronizer.isEmptySynchro()) {
						msg = getString(R.string.empty_update_message);
					} else {
						if (dbSynchronizer.isSynchroWithErrors()) {
							msg = getString(R.string.update_db_err_message);
						} else {
							msg = getString(R.string.update_success_message);
						}
					}
					// envoie le nombre de clics au serveur
					dbSynchronizer.sendStatsUsage();

				} catch (Exception e) {
					msg = getString(R.string.connection_err_message);
				}

				// fill sheet term classifier with data from the database
				SheetTermClassifier termClassifier = MaxCom.getTermClassifier();
				DatabaseHelper dbHelper = MaxCom.getDatabaseHelper();
				dbHelper.open();
				List<Sheet> sheets = dbHelper.getSheets();
				List<Term> terms = dbHelper.getTerms();
				List<Taxonomy> taxonomys = dbHelper.getTaxonomys();
				termClassifier.fillWithData(sheets, terms, taxonomys);
				dbHelper.close();
				final String fmsg = msg;
				SplashScreenActivity.this.runOnUiThread(new Runnable() {
					public void run() {
						Toast.makeText(SplashScreenActivity.this, fmsg,
								Toast.LENGTH_SHORT).show();
					}
				});
				Intent intent = new Intent(SplashScreenActivity.this,
						MainScreenActivity.class); // on
				// lance
				// l'application
				// principale
				startActivity(intent);
				finish();
			}
		}
	};

}