/**
 * Project: Max'Com: an oral communication software solution that provides
 * pre-recorded sound <-> daylife image / word associations. Autistic people
 * or persons with communication problems are to be the main users. The
 * content is sorted by categories that helps users to express themselves
 * according to the context.
 * File name: ZipFileReader.java
 * Description: this class is used to store compressed files.
 * 
 * @author Telecom Lille1 on 2010-11-23
 * @copyright 2010 Max'Com team. All rights reserved.
 * @version $Id: code-gpl-license.txt,v 1.2 2004/05/04 13:19:30 garry Exp $
 * 
 * @see The GNU Public License (GPL) version 3 or higher
 *
 * 
 * Max'Com is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 3 of the License, or 
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License 
 * for more details.
 * 
 * You should have received a copy of the GNU General Public License along 
 * with this program; if not, write to the Free Software Foundation, Inc., 
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

package maxcom.mobile;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.logging.Level;
import java.util.logging.Logger;
import java.util.zip.ZipEntry;
import java.util.zip.ZipInputStream;

public class ZipFileReader {
	/**
	 * Lister les fichiers contenus dans le zip
	 * @param archive nom du fichier zip
	 * @return liste sous forme ['nom, 'taille', 'date']
	 */
	@SuppressWarnings("finally")
		public static ArrayList<String[]> getFiles(String archive) {
			ArrayList<String[]> fileList = new ArrayList<String[]>();
			ZipInputStream zipInputStream = null;
			ZipEntry zipEntry = null;
			Long size;

			try {
				zipInputStream = new ZipInputStream(new FileInputStream(archive));
				zipEntry = zipInputStream.getNextEntry();
				while (zipEntry != null) {
					String[] file = new String[3];
					file[0] = zipEntry.getName();
					size = zipEntry.getSize()/1024;
					file[1] = size.toString()+ " ko";
					SimpleDateFormat simpleDateFormat = new SimpleDateFormat("dd/MM/yyyy HH:mm");
					file[2] = simpleDateFormat.format(new Date(zipEntry.getTime()));

					fileList.add(file);
					zipEntry = zipInputStream.getNextEntry();
				}
			} catch (FileNotFoundException ex) {
				Logger.getLogger(ZipFileReader.class.getName()).log(Level.SEVERE, null, ex);
			} finally {
				try {
					zipInputStream.close();
				} catch (IOException ex) {
					Logger.getLogger(ZipFileReader.class.getName()).log(Level.SEVERE, null, ex);
				}
				return fileList;
			}
		}

	/**
	 * Extraire un fichier
	 * @param archive fichier zip
	 * @param file nom du fichier a extraire
	 * @param destPath repertoire de destination du fichier
	 * @throws FileNotFoundException
	 * @throws IOException
	 */
	public static void extractTo(String archive, String file, String destPath) throws FileNotFoundException, IOException {
		ZipInputStream zipInputStream = null;
		ZipEntry zipEntry = null;
		byte[] buffer = new byte[2048];

		zipInputStream = new ZipInputStream(new FileInputStream(archive));
		zipEntry = zipInputStream.getNextEntry();
		while (zipEntry != null) {
			if (zipEntry.getName().equalsIgnoreCase(file)) {
				FileOutputStream fileoutputstream = new FileOutputStream(destPath + file);
				int n;

				while ((n = zipInputStream.read(buffer, 0, 2048)) > -1) {
					fileoutputstream.write(buffer, 0, n);
				}

				fileoutputstream.close();
				zipInputStream.closeEntry();

			}
			zipEntry = zipInputStream.getNextEntry();
		}
	}
}
