<?php
/**
 * Admin Class
 *
 * Dashboard d'admin 
 *
 * @package		Maxcom
 * @category	Controller
 * @author		Maxcom Development Team
 * @link		
 */
class Admin extends CI_Controller
{
	/**
	 * Affiche la page d'accueil de l'administration
	 */
	function index() {
		if ($this->maxcomutils->checkSession()) {			
			$space_id = $this->session->userdata('space_id');
			
			$sheets = $this->sheet->get_all($space_id);
				
			$view_data = array();
			$view_data['sheets'] = $sheets;
			$view_data['contacts'] = $this->user->get_admin($space_id);
			
			$last_sync = $this->space->last_sync($space_id);
			$view_data['last_sync'] = $this->maxcomutils->convert_date($last_sync);
			
			$view_data['ten_last_sheets'] = $this->sheet->ten_last_modif($space_id);
			$view_data['ten_last_cats'] = $this->category->ten_last_modif($space_id);
			
			$this->maxcomutils->load_view('main-admin', $view_data);
		}
	}
	
	/**
	 * Affiche le formulaire de contact
	 */
	function contact() {
		if ($this->maxcomutils->checkSession()) {
			$user = $this->user->get($this->session->userdata('user_id'));
			$data['name'] = $user['firstname'].' '.$user['lastname'];
			$this->load->view('contact-form',$data);
		}
	}
	
	/**
	 * Envoi le formulaire de contact avec toutes les infos
	 */
	// TODO: Créer un template de mail
	function contact_send() {
		if ($this->maxcomutils->checkSession()) {
			$user = $this->user->get($this->session->userdata('user_id'));
			$this->load->helper('string');
			$name = $user['name'].' '.$user['lastname'];
			$mail = $user['mail'];
			$incident = '[Max\'Com incident-'.$user['space_id'].'-'.random_string('alnum',6).']';
			$objet = utf8_decode($incident.$this->input->post('objet'));
			$message = $this->input->post('message');
	
$template_mail = 
"Bonjour ".$name.",

Ton message a bien été envoyé au support Max'Com. Il sera traité dans les plus brefs délais. Tu peux retrouver le suivi de cet incident à cette adresse: https://groups.google.com/forum/#!searchin/support-maxcom/".$incident."

Voici le résumé de ta demande:

Objet: ".$this->input->post('objet')."

".$message."

À très bientôt,

L'équipe Max'Com";	
			$this->load->library('email');
				
			//Envoi du mail de confirmation à l'auteur du bug
			$this->email->from('support-maxcom@googlegroups.com', 'Support Max\'Com');
			$this->email->to($mail);
			$this->email->subject('[Max\'Com]Confirmation d\'envoi du rapport de bug');
			$this->email->message($template_mail);	
			$this->email->send();
			
			$this->email->clear();
			
			//Envoi du mail sur la boîte mail du support
			$this->email->from($mail, $name);
			$this->email->to('support-maxcom@googlegroups.com');
			$this->email->subject($objet);
			$this->email->message($message);	
			$this->email->send();
			
			echo "<span class='label success'>OK</span><span> Votre mail a bien été envoyé au support avec l'adresse $mail</span>";
		}
	}
	
	/**
	 * Fonction qui récupère le flux Twitter du projet Max'Com pour l'afficher dans une box
	 * de la page d'accueil de l'admin.
	 * Cette fonction est appelée en ajax.
	 */
	function getTwitterNews() {
		if ($this->maxcomutils->checkSession()) {
			$this->load->library('RSSParser', array('url' => 'https://api.twitter.com/1/statuses/user_timeline.rss?screen_name=projetmaxcom', 'life' => 0));
			$data = $this->rssparser->getFeed(5);
		
			foreach ($data as $item) :
				echo "<li class='twit'><b>" . $this->_convertDateTwitter($item['pubDate']) . ": </b><br>" . $this->_parse_tweet(substr($item['description'], 13)) . "</li>";
			endforeach; 
		
			echo "<li><a target='_blank' href='https://twitter.com/#!/projetmaxcom'>Voir la suite...</a></li>";
		}
	}
	
	/**
	 * Fonction qui va parser le flux Twitter indiqué en paramètre
	 * @param string $tweet Flux Twitter en entrée
	 * @return string le flux Twitter décrypté
	 */
	private function _parse_tweet($tweet) {
		$search = array('|(http://[^ ]+)|', '/(^|[^a-z0-9_])@([a-z0-9_]+)/i', '/(^|[^a-z0-9_])#([a-z0-9_]+)/i');
		$replace = array('<a target="_blank"  href="$1">$1</a>', '$1<a target="_blank" href="http://twitter.com/$2">@$2</a>', '$1<a target="_blank" href="http://search.twitter.com/search?q=#$2">#$2</a>');
		$tweet = preg_replace($search, $replace, $tweet);
		return $tweet;
	}

	/**
	 * Conversion d'une date d'un format américain en format Français
	 * @param date $date
	 * @return string la date au format "Lundi 01 Janvier 2000 à 00h00"
	 */
	private function _convertDateTwitter($date) {
		$days = array(
			'Mon'=>'Lundi',
			'Tue'=>'Mardi',
			'Wed'=>'Mercredi',
			'Thu'=>'Jeudi',
			'Fri'=>'Vendredi',
			'Sat'=>'Samedi',
			 'Sun'=>'Dimanche'
		);
		$months = array(
			'Jan'=>'Janvier',
			'Feb'=>'Février',
			'Mar'=>'Mars',
			'Apr'=>'Avril',
			'May'=>'Mai',
			'Jun'=>'Juin',
			'Jul'=>'Juillet',
			'Aug'=>'Août',
			'Sep'=>'Septembre',
			'Oct'=>'Octobre',
			'Nov'=>'Novembre',
			'Dec'=>'December'
		);
		        	
		$date = substr($date, 0, -6);
		$day = $days[substr($date, 0, 3)];
		$day_num = substr($date, 5, 2);
		$month = $months[substr($date, 8, 3)];
		$year = substr($date, 12, 4);
		$hour = substr($date, 17, 2);
		$minute = substr($date, 20, 2);
		$second = substr($date, 24, 2);
		        	
		return $day . " " . $day_num . " " . $month . " " . $year . " à " . $hour . "h" . $minute;
	}
	
	/**
	 * Fonction qui convertit un tableau de valeurs en graphique simple
	 * @param array $table: Valeurs des données
	 * @param string $color: Couleur de la couleur au format HTML
	 */
	function single_chart($table=NULL,$color="76A4FB") {
		if ($this->maxcomutils->checkSession()) {
			$extract = $this->stats->last_stats($this->session->userdata('space_id'));
			
			foreach ($extract as $item) {
				$datas[] = $item[$table];
				$dates[] = $this->maxcomutils->convert_date($item['date'],'daymonth');
			}
			
			if (!empty($datas)) {
				$datas = array_reverse($datas);
				$dates = array_reverse($dates);
				
				$maxvalue = max($datas);
				$stat_data = '';
				$stat_date = '';
				
				foreach ($datas as $item) {
					$stat_data .= $item.',';
				}
				$stat_data = substr($stat_data, 0, -1);
				
				foreach ($dates as $date) {
					$stat_date .= '|'.$date;
				}
				
				echo "<img src='http://chart.apis.google.com/chart?".
				"chxl=0:$stat_date|2:|Low|High".
				"&chxr=0,0,$maxvalue".
				"&chds=a&chxs=0,676767,11.5,0,lt,676767".
				"&chxt=x,y".
				"&chs=250x150".
				"&cht=lc".
				"&chxtc=0,2".
				"&chco=$color".
				"&chd=t:$stat_data".
				"&chls=3".
				"&chf=bg,s,F0F0F0' />";
			}
		}
	}
	
	function post_install() {
		rename('install/index.php', 'install/index_save');
		copy('install/post_install.php', 'install/index.php');
		
		redirect('admin','refresh');
	}
	
	function get_trunk_version() {
			$ch = curl_init ("http://maxcom.googlecode.com/svn/MaxComServer/trunk/version");
			curl_setopt ($ch, CURLOPT_RETURNTRANSFER, true);
			return json_decode(curl_exec ($ch), TRUE);
	}
	
	function get_current_version() {
		$this->load->library('file');
		return json_decode(read_file('version'), TRUE);
	}
}
?>
