<?php
/**
 * Maxcom 
 *
 * Solution opensource pour des personnes presentant des troubles de la communication
 *
 * @author		Maxcom Development Team
 * @copyright	Copyright (c) Association Dynamots.
 * @license		http://www.maxcom.fr/license.html
 * @link		http://www.maxcom.fr
 * @since		Version 1.0
 * @filesource  
 */

// ------------------------------------------------------------------------

/**
 * CategoryAdmin Class
 *
 * Permet la gestion des categories
 *
 * @package		Maxcom
 * @category	Controller
 * @author		Maxcom Development Team
 * @link		
 */

class CategoryAdmin extends CI_Controller
{
	
	/**
	 * 	Affiche la page principale de gestion des catégories
	 */
	function index()
	{
		$this->load->helper(array('form', 'url'));
		
		$this->load->library('form_validation');
		
		if ($this->maxcomutils->checkSession()) {
			$space_id = $this->session->userdata('space_id');
			
			$categories = $this->category->get_all($space_id);
			$view_data['categories'] = $categories;
			$view_data['action'] = '';
			$this->maxcomutils->load_view('main-category', $view_data);
			
		}
	}
	
	/**
	 * 	Affiche la page de création des catégories
	 */
	function ui_add() {
		if ($this->maxcomutils->checkSession()) {
			$view_data['update'] = false;
			
			$view_data['category_name'] = '';
			$view_data['category_description'] = '';
			$view_data['category_rank'] = 5;
			$view_data['category_parent'] = 0;
			$view_data['error'] = '';
			
			$space_id = $this->session->userdata('space_id');

			$categories = $this->category->get_all($space_id);
			
			$view_data['categories'] = $categories;
			
			$this->maxcomutils->load_view('edit-category', $view_data);
		}
	}
	
	/**
	 * Affiche la page de modification des catégories
	 * @param int $updated_id: Identifiant de la catégorie à mettre à jour
	 */
	function ui_update($updated_id) {
		if ($this->maxcomutils->checkSession()) {				
			// recuperation donnee pour la vue

			$category_data = $this->category->get($updated_id);
			
			if ($this->maxcomutils->checkUserRights($category_data['space_id'],$category_data['author_id'])){
			
				$view_data = array();
				
				$view_data['update'] = true;
				$view_data['category_id'] = $updated_id;
				$view_data['category_name'] = $category_data['name'];
				$view_data['category_description'] = $category_data['description'];
				$view_data['category_image'] = $category_data['image'];
				$view_data['category_rank'] = $category_data['rank'];
				$view_data['category_parent'] = $category_data['parent_id'];
				$view_data['error'] = '';
				
				$space_id = $this->session->userdata('space_id');
	
				$categories = $this->category->get_all($space_id);
				
				$view_data['categories'] = $categories;
	
					
				$this->maxcomutils->load_view('edit-category', $view_data); 
				}else
				redirect('categoryadmin', $category_data);			
		}	
	}

	/**
	 * Affiche la page de création des catégories en cas d'erreur
	 * @param string $error: Erreur rencontrée
	 */
	function ui_with_error($error) {
		if ($this->maxcomutils->checkSession()) {
			$view_data['update'] = false;
			$view_data['category_name'] = '';
			$view_data['category_description'] = '';
			$view_data['category_rank'] = 5;
			$view_data['category_parent'] = 0;
			$view_data['error'] = $error;
				
			$space_id = $this->session->userdata('space_id');

			$categories = $this->category->get_all($space_id);
				
			$view_data['categories'] = $categories;

	
			$this->maxcomutils->load_view('edit-category', $view_data);
		}
	}
	
	/**
	 * 	Création d'une catégorie et rattachement au spacee courant 
	 * -on verifie que l'image est s�r avant de le metre dans le serveur
	 */  
	function add() {
		if ($this->maxcomutils->checkSession()) {
			$category_data = $this->_extract_data();
			
			$image_data = $this->_upload_img();
			if ((! empty($image_data))) {
				if ($image_data['image_width'] > 800 || $image_data['image_height'] > 600) {
					$config['image_library'] = 'gd2';
					$config['source_image']	= $image_data['full_path'];
					$config['maintain_ratio'] = TRUE;
					$config['width'] = 800;
					$config['height'] = 600;
					
					$this->load->library('image_lib');
					$this->image_lib->initialize($config);
					$this->image_lib->resize();
					$this->image_lib->clear();
				}
				$category_data['image'] = $image_data['file_name'];
				$this->_create_thumbnail($image_data['full_path']);
				$space_id = $this->session->userdata('space_id');
				$category_data['space_id'] = $space_id;
				
				$this->load->helper('date');
				$datestring = "%Y-%m-%d %H:%i:%s";
				$category_data['last_modif'] =  mdate($datestring);
				$category_data['date'] =  mdate($datestring);
				$category_data['author_id'] = $this->session->userdata('user_id');

				$category_id = $this->category->create($category_data);
				
				// Insertion dans la table LogQueries
				$log_datas['image'] = $category_data['image'];
				$log_datas['rank'] = $category_data['rank'];
				$log_datas['name'] = $category_data['name'];
				$log_datas['parent_id'] = $category_data['parent_id'];
				$log_datas_json = json_encode($log_datas);
				
				$where = json_encode(array('id',$category_id));
				
				$this->load->model('logqueries');
				$this->logqueries->addquery($space_id, 'INSERT', 'category', $log_datas_json, $where);
				
				redirect('categoryadmin', 'refresh');
			}
			else {
				$this->ui_with_error("Image_upload");
			}
		}
	}
	
	/**
	 * Mise à jour d'une catégorie
	 * @param int $category_id: Identifiant de la catégorie à mettre à jour
	 */ 
	function update($category_id) {
		if ($this->maxcomutils->checkSession()) {
			// recuperation donnees courants de la categorie pour le nettoyage des fichiers 
			$stored_data = $this->category->get($category_id);
			
			$category_data = $this->_extract_data();
			
			$image_data = $this->_upload_img();
			
			//TODO: verif sur l'image;
			if ((! empty($image_data))) {
				if ($image_data['image_width'] > 800 || $image_data['image_height'] > 600) {
					$config['image_library'] = 'gd2';
					$config['source_image']	= $image_data['full_path'];
					$config['maintain_ratio'] = TRUE;
					$config['width'] = 800;
					$config['height'] = 600;
					
					$this->load->library('image_lib');
					$this->image_lib->initialize($config);
					$this->image_lib->resize();
					$this->image_lib->clear();
				}
				$category_data['image'] = $image_data['file_name'];
				$log_datas['image'] = $category_data['image'];
				$this->_create_thumbnail($image_data['full_path']);
				
				// suppression de l'ancienne image 
				$image = $stored_data['image']; 
				$path = 'uploads/images/categories/'.$image;
				if (file_exists($path)) {
					unlink($path);
				}
				
				$path = 'uploads/images/thumbnails/'.$image;
				if (file_exists($path)) {
					unlink($path);
				}			
			} else {
				// on conserve l'image courant si probleme de chargement
				unset($category_data['image']);
				$log_datas['image'] = $stored_data['image'];
			} 
					
			$category_data['id'] = $category_id; 
			
			$space_id = $this->session->userdata('space_id');
			$category_data['space_id'] = $space_id;
			
			$this->load->helper('date');
			$datestring = "%Y-%m-%d %H:%i:%s";
			$category_data['last_modif'] =  mdate($datestring);
			
			$this->category->update($category_data);	
			
			// Insertion dans la table LogQueries
			$log_datas['name'] = $category_data['name'];
			$log_datas['rank'] = $category_data['rank'];
			$log_datas['parent_id'] = $category_data['parent_id'];
			
			$log_datas_json = json_encode($log_datas);
			$where = json_encode(array('id',$category_id));
						
			$this->load->model('logqueries');
			$this->logqueries->addquery($space_id, 'UPDATE', 'category', $log_datas_json, $where);
			
			redirect('categoryadmin', 'refresh');
		}
	}
	
	
	/**
	 * Suppresion d'une catégorie
	 * @param int $category_id: Identifiant de la catégorie à supprimer
	 */
	function delete($category_id) {
		if ($this->maxcomutils->checkSession()) {
			$category_data = $this->category->get($category_id);
			
			if ($this->maxcomutils->checkUserRights($category_data['space_id'],$category_data['author_id'])){
			
				$image = $category_data['image']; 
				$path = 'uploads/images/categories/'.$image;
				if (file_exists($path)) {
					unlink($path);
				}
				
				$path = 'uploads/images/thumbnails/'.$image;
				if (file_exists($path)) {
					unlink($path);
				}
				
				$this->category->delete($category_id);	
				
				$where = json_encode(array('id',$category_id));
				
				//Insertion de la requête delete dans la table LogQueries
				$this->load->model('logqueries');
				$this->logqueries->addquery($category_data['space_id'], 'DELETE', 'category', '', $where);
				
				//TODO: Insertion de la requête modif fiches avec cette catégorie et sous catégories avec cette catégorie (à valider...)
				redirect('categoryadmin', 'refresh');
			}else{
				redirect('categoryadmin', $category_data);
			}
		}
	}
	
	/**
	 * Extrait les données fournies par l'utilisateur (Fonction privée) 
	 * @return multitype:string NULL
	 */ 
	function _extract_data() {
		$category_data = array();
		
		$category_data['id'] = '';
		$category_data['name'] = $this->input->post('name');	
		$category_data['description'] = $this->input->post('description');	
		$category_data['image'] = $this->input->post('image');
		$category_data['rank'] = $this->input->post('rank');
		$category_data['parent_id'] = $this->input->post('parent');
		
		return $category_data;
	}
	
	/**
	 * Récupère l'image fournie par l'utilisateur (fonction privée)
	 * @return multitype:
	 */
	function _upload_img() {
		$config['upload_path'] = './uploads/images/categories';
		$config['allowed_types'] = 'gif|jpg|png';
		$config['max_size']	= '0';
		$config['max_width']  = '0';
		$config['max_height']  = '0';
		$config['encrypt_name'] = true;

		$this->load->library('upload', $config);
		
		if (! $this->upload->do_upload('image'))
		{
			return array();
		}
		else
		{
			return $this->upload->data();
		}
	}
	
	/**
	 * Crée la vignette d'une image (fonction privée)
	 * @param string $full_path
	 */
	function _create_thumbnail($full_path) {
		$config['image_library'] = 'gd2';
		$config['source_image']	= $full_path;
		$config['new_image'] = './uploads/images/thumbnails/';
		$config['maintain_ratio'] = TRUE;
		$config['width'] = 150;
		$config['height'] = 100;
		
		$this->load->library('image_lib');
		$this->image_lib->initialize($config);
		if ( ! $this->image_lib->resize())
		{
			echo $this->image_lib->display_errors();
		}
	}
}
?>
