<?php
/**
 * Maxcom 
 *
 * Solution opensource pour des personnes presentant des troubles de la communication
 *
 * @author		Maxcom Development Team
 * @copyright	Copyright (c) Association Dynamots.
 * @license		http://www.maxcom.fr/license.html
 * @link		http://www.maxcom.fr
 * @since		Version 1.0
 * @filesource  
 */

// ------------------------------------------------------------------------

/**
 * Logging Class
 *
 * Gere les journalisations des terminaux mobiles
 * Deux types de journalisations: erreurs et nombre de clics sur les images 
 *
 * @package		Maxcom
 * @category	Controler
 * @author		Maxcom Development Team
 * @link				
 */

class Logging extends CI_Controller
{
		
	/**
	 * Ajoute un nouvel enregistrement de journalisation
	 * @param string $login: Login de l'utilisateur
	 * @param string $password: Mot de passe encrypté en MD5
	 */
	function add_record($login, $password) {

		$user_data = $this->user->check($login, $password);				
		if (!empty($user_data)) {
			$user_id = $user_data['id'];
					
			$content = file_get_contents('php://input');

			$logging_data = $this->_parse_record($content);
			
			$logging_data['user_id'] = $user_id;
			$logging_data['date'] = date('Y-m-d H:i:s'); // a changer
			$logging_data['resolved'] = false;
					
			$this->load->model('dblogging');
			$this->dblogging->create($logging_data); 
		}
		else {
			// return a 404 error 
			set_status_header(404);
		} 
	}
	
	/**
	 * Extrait l'enregistrement du corps de la requete
	 * @param $content
	 */
	function _parse_record($content) {
		
		$json_part  = strtok($content, '{}');
		$json_str = '{'.$json_part.'}';
				
		$json_val = json_decode($json_str, true);
		
		$record_part = strtok('');
		
		$data = array();
		$data['terminal_id'] = $json_val["id"];
		$data['model'] = $json_val["model"];		
		$data['sdk_version'] = $json_val["version"]; 
		$data['record'] = $record_part;		
		
		return $data;
	} 

	/**
	 * Recuperation des statistiques et consolidation dans la base 
	 * format des données JSON en entrée : 
	 * {"id": "device_id", "model": "device_model", "clicks":{"id1": "val1", ..., "idN": "valn"} 
	 * @param string $login: Login de l'utilisateur
	 * @param string $password: Mot de passe encrypté en MD5
	 */
	function  process_stats($login, $password) {
		
		$user_data = $this->user->check($login, $password);				
		if (!empty($user_data)) {
			$user_id = $user_data['id'];
								
			$content = file_get_contents('php://input');
			
			$stats_data = $this->parse_stats($content);			
						
			$clicks = $stats_data['clicks'];
			foreach($clicks as $id => $nbclick) {
				$this->sheet->update_clicks($id, $nbclick);
			} 
		}
		else {
			// return a 404 error
			set_status_header(404);
		} 
	}
	
	/**
	 * Extrait les statistiques du corps de la requête
	 * @param unknown_type $content
	 * @return multitype:unknown
	 */
	function parse_stats($content) {		
		$json_val = json_decode($content, true);

		$data = array();
		$data['terminal_id'] = $json_val['id'];
		$data['model'] = $json_val['model'];		
		$data['clicks'] = $json_val['clicks']; 
		
		return $data;
	} 
	
	/**
	 * Affiche le détail d'une erreur
	 * @param int $id: identifiant du log dans la table logging
	 */
	function detail($id=NULL) {
		if ($this->maxcomutils->checkSession()) {
			if ($id) {
				$this->load->model('dblogging');
				$datas['details'] = $this->dblogging->get($id);
			} else {
				$datas['details'] = array();
			}
			
			$this->maxcomutils->load_viewPopup('logging_detail',$datas);
		}
	}
}

?>
