<?php
/**
 * Maxcom 
 *
 * Solution opensource pour des personnes presentant des troubles de la communication
 *
 * @author		Maxcom Development Team
 * @copyright	Copyright (c) Association Dynamots.
 * @license		http://www.maxcom.fr/license.html
 * @link		http://www.maxcom.fr
 * @since		Version 1.0
 * @filesource  
 */

// ------------------------------------------------------------------------

/**
 * SheetAdmin Class
 *
 * Permet la gestion des fiches 
 *
 * @package		Maxcom
 * @category	Controller
 * @author		Maxcom Development Team
 * @link		
 */

class SheetAdmin extends CI_Controller
{
		
	// TODO Faire le lien avec la table Taxonomy ?? 
	

	/**
	 * 	Affiche la page principale de gestion des fiches
	 */
	function index() {
		if ($this->maxcomutils->checkSession()) {			
			$space_id = $this->session->userdata('space_id');
				
			$sheets = $this->sheet->get_all($space_id);
				
			$view_data = array();
			$view_data['sheets'] = $sheets;	
			$view_data['action'] = '';

			$this->maxcomutils->load_view('main-sheet', $view_data);
		}
	}

	/**
	 * Affiche la page principale de gestion des fiches en filtrant selon l'id de la catégorie donnée
	 * @param int $category_id: Identifiant de la catégorie à filtrer
	 */
	function categoryfilter($category_id) {
		if ($this->maxcomutils->checkSession()) {
			$space_id = $this->session->userdata('space_id');
			$sheets = $this->sheet->filter($category_id,$space_id);
			$category_name = $this->category->get_name($category_id);
			$view_data['sheets'] = $sheets;
			$view_data['action'] = 'filter';
			$view_data['keyword'] = $category_name;
			echo $this->db->last_query();
			$this->maxcomutils->load_view('main-sheet', $view_data);
		}
	}
	
	/**
	 * 	Affiche la page de creation d'une fiche
	 */
	function ui_add() {
		if ($this->maxcomutils->checkSession()) {
			$view_data['update'] = false;

			$space_id = $this->session->userdata('space_id');
			$categories = $this->category->get_all($space_id);
			$category =  !empty($categories) ? $categories[0]->id : 0;
			
			// default value
			$view_data['sheet_name'] = '';
			$view_data['sheet_status'] = 0;
			$view_data['sheet_favorite'] = 0;
			$view_data['sheet_note'] = 0;
			$view_data['sheet_category'] = 'Aucune';
			$view_data['sheet_description'] = '...';		
			$view_data['categories'] = $categories;
			$view_data['error'] = '';
			$view_data['tags'] = '[]';
				
			$this->maxcomutils->load_view('edit-sheet', $view_data);
		}
	}
	
	/**
	 * Affiche la page de modification d'une fiche
	 * @param int $updated_id: Identifiant de la fiche à modifier
	 */
	function ui_update($updated_id) {
		if ($this->maxcomutils->checkSession()) {				
			// recuperation donnee pour la vue
			//TODO verification des droit sur la fiche d'identifient $updated_id
			
			$sheet_data = $this->sheet->get($updated_id);
			
			if ($this->maxcomutils->checkUserRights($sheet_data['space_id'],$sheet_data['author_id'])){
								
				$this->load->model('taxonomy');
				$tags = $this->taxonomy->get_tags_of_sheet($updated_id);
				$tags = json_encode($tags);
			
				$view_data = array();
				
				$view_data['update'] = true;
				$view_data['sheet_id'] = $updated_id;
				$view_data['sheet_name'] = $sheet_data['name'];
				$view_data['sheet_image'] = $sheet_data['image'];
				$view_data['sheet_sound'] = $sheet_data['sound'];
				$view_data['sheet_status'] = $sheet_data['status'];
				$view_data['sheet_favorite'] = $sheet_data['favorite'];
				$view_data['sheet_note'] = $sheet_data['note'];
				$view_data['sheet_category'] = $sheet_data['category_id'];
				$view_data['sheet_description'] = $sheet_data['description'];
				$view_data['error'] = '';
				$view_data['tags'] = $tags;
						
				$space_id = $this->session->userdata('space_id');
				$categories = $this->category->get_all($space_id);
					
				$view_data['categories'] = $categories;
				
				$this->maxcomutils->load_view('edit-sheet', $view_data);
			} else 
			redirect('sheetadmin', $sheet_data);
		}	
	}
	
	/**
	 * Affiche la page de création d'une fiche avec un message d'erreur
	 * @param string $error: Erreur à afficher
	 */
	function ui_with_error($error) {
		if ($this->maxcomutils->checkSession()) {
			$space_id = $this->session->userdata('space_id');
			$categories = $this->category->get_all($space_id);
			$category =  !empty($categories) ? $categories[0]->id : 0;
			
			$view_data['update'] = false;
			$view_data['sheet_name'] = '';
			$view_data['sheet_status'] = 0;
			$view_data['sheet_favorite'] = 0;
			$view_data['sheet_note'] = 0;
			$view_data['sheet_category'] = $category;
			$view_data['sheet_description'] = '...';		
			$view_data['categories'] = $categories;
			$view_data['error'] = $error;
			$view_data['tags'] = '[]';
	
			$view_data['categories'] = $categories;	
			$this->maxcomutils->load_view('edit-sheet', $view_data);
		}
	}
	
	/**
	 * 	Création d'une fiche et rattachement à l'espace courant 
	 */  
	function add() {
		if ($this->maxcomutils->checkSession()) {
			$sheet_data = $this->_extract_data();
			
			$img_uploaded = false; 
			$image_data = $this->_upload_img();
			

			if ((! empty($image_data))) {
				if ($image_data['image_width'] > 800 || $image_data['image_height'] > 600) {
					$config['image_library'] = 'gd2';
					$config['source_image']	= $image_data['full_path'];
					$config['maintain_ratio'] = TRUE;
					$config['width'] = 800;
					$config['height'] = 600;
					
					$this->load->library('image_lib');
					$this->image_lib->initialize($config);
					$this->image_lib->resize();
					$this->image_lib->clear();
				}
				$sheet_data['image'] = $image_data['file_name'];
				$this->_create_thumbnail($image_data['full_path']);
				$img_uploaded = true; 
				
				if (! $img_uploaded) {
					// TODO else mettre une image par defaut ou envoye une erreur
				}
				
				$space_id = $this->session->userdata('space_id');
				$sheet_data['space_id'] = $space_id;
				
				$user_id = $this->session->userdata('user_id');
				$sheet_data['author_id'] = $user_id;
				$sheet_data['description'] = '';
				
				$this->load->helper('date');
				$datestring = "%Y-%m-%d %H:%i:%s";
				$sheet_data['date'] =  mdate($datestring);
				$sheet_data['last_modif'] =  mdate($datestring);
				
				$sheet_data['id'] = $sheet_id = $this->sheet->create($sheet_data);
				
				$where = json_encode(array('id',$sheet_id));
				
				//TODO: Insertion dans la table logqueries
				// Données à insérer: name, image, favorite, status, nbclics, date, last_modif, space, category_id, note, author_id
				// Toutes les données sont elles nécessaires?
				
				unset($sheet_data['space_id']);
				unset($sheet_data['id']);
				unset($sheet_data['description']);
				$log_datas_json = json_encode($sheet_data);
				$this->load->model('logqueries');
				$this->logqueries->addquery($space_id, 'INSERT', 'sheet', $log_datas_json, $where);
				
				$tags = $this->input->post('tags');
				$this->_manage_tags($tags, $sheet_id, $space_id);
				
				redirect('sheetadmin', 'refresh');
				}
			else {
				$this->ui_with_error("Image_upload");
			}
		}
	}
	
	/**
	 * Mise a jour d'une fiche  
	 * @param int $sheet_id: Identifiant de la fiche à modifier
	 */  
	function update($sheet_id) {
		if ($this->maxcomutils->checkSession()) {
			// recuperation donnees courants de la fiche pour le nettoyage des fichiers 
			$stored_data = $this->sheet->get($sheet_id);
			
			$sheet_data = $this->_extract_data();
									
			$image_data = $this->_upload_img();
			
			if ((! empty($image_data))) {
				if ($image_data['image_width'] > 800 || $image_data['image_height'] > 600) {
					$config['image_library'] = 'gd2';
					$config['source_image']	= $image_data['full_path'];
					$config['maintain_ratio'] = TRUE;
					$config['width'] = 800;
					$config['height'] = 600;
					
					$this->load->library('image_lib');
					$this->image_lib->initialize($config);
					$this->image_lib->resize();
					$this->image_lib->clear();
				}			
				$sheet_data['image'] = $image_data['file_name'];
				$this->_create_thumbnail($image_data['full_path']);
				
				// suppression de l'ancienne image et de sa vignette
				$image = $stored_data['image']; 
				$path = 'uploads/images/sheets/'.$image;
				if (file_exists($path)) {
					unlink($path);
				}
	
				$path = 'uploads/images/thumbnails/'.$image;
				if (file_exists($path)) {
					unlink($path);
				}			
			} else {
				// on conserve l'image actuele si probleme chargement
				//unset($sheet_data['image']);
				$sheet_data['image'] = $stored_data['image'];
			} 
			
			$space_id = $this->session->userdata('space_id');
			$sheet_data['space_id'] = $space_id;
			
			//On vérifie d'abord si il y'a des différences entre le formulaire
			//et ce que l'on a en base (pour éviter de loguer inutilement dans dbaction
			$sheet_data['id'] = $sheet_id;
			unset($stored_data['nbclics']);
			unset($stored_data['date']);
			unset($stored_data['author_id']);
			unset($stored_data['last_modif']);
			
			$diff = array_diff_assoc($sheet_data,$stored_data);
				
			if (!empty($diff)){
				$this->load->helper('date');
				$datestring = "%Y-%m-%d %H:%i:%s";
				$sheet_data['last_modif'] =  mdate($datestring);
				
				$this->sheet->update($sheet_data);
				$where = json_encode(array('id',$sheet_id));
				
				//TODO: Insertion dans la table logqueries
				unset($sheet_data['id']);
				unset($sheet_data['space_id']);
				
				$log_datas_json = json_encode($sheet_data);
				$this->load->model('logqueries');
				$this->logqueries->addquery($space_id, 'UPDATE', 'sheet', $log_datas_json, $where);
			}
			
			$tags = $this->input->post('tags');
			$this->_manage_tags($tags, $sheet_id, $space_id);
			
			redirect('sheetadmin', 'refresh');
		}
	}
	
	
	/**
	 * Suppression d'une fiche  
	 * @param int $sheet_id: Identifiant de la fiche à supprimer
	 */
	function delete($sheet_id) {
		if ($this->maxcomutils->checkSession()) {
			
			$sheet_data = $this->sheet->get($sheet_id);
			
			if ($this->maxcomutils->checkUserRights($sheet_data['space_id'],$sheet_data['author_id'])){	
				
				$image = $sheet_data['image']; 
				$path = 'uploads/images/sheets/'.$image;
				if (file_exists($path)) {
					unlink($path);
				}
					
				$path = 'uploads/images/thumbnails/'.$image;
				if (file_exists($path)) {
					unlink($path);
				}
				
				
				$sound = $sheet_data['sound'];
				$path = 'uploads/sound/sheets'.$image;
				if (file_exists($path)) {
					unlink($path);
				}	
				
				$this->load->model('taxonomy');
				$this->taxonomy->delete($sheet_id);
				
				$this->sheet->delete($sheet_id);
				
				$where = json_encode(array('id',$sheet_id));
				
				$this->load->model('logqueries');
				$this->logqueries->removequery($where, 'taxonomy');
				$this->logqueries->addquery($sheet_data['space_id'], 'DELETE', 'sheet', '', $where);
				
				redirect('sheetadmin', 'refresh');
			}else 
				redirect('sheetadmin', $sheet_data);
		}
	}
	
	/**
	 * Extrait les donnees fournies par l'utilisateur (fonction privée) du formulaire
	 * @return multitype:string number NULL
	 */
	function _extract_data() {
		$sheet_data = array();
		
		$sheet_data['id'] = '';
		$sheet_data['name'] = $this->input->post('name');
		$sheet_data['status'] = $this->input->post('status');
		$sheet_data['favorite'] = ($this->input->post('favorite') == 'on' ? 1 : 0);
		$sheet_data['note'] = $this->input->post('note');
		$sheet_data['category_id'] = $this->input->post('category');
		
		return $sheet_data;
	}

	/**
	 * Récupère l'image fournie par l'utilisateur 
	 * @return multitype:
	 */
	function _upload_img()
	{
		$config['upload_path'] = './uploads/images/sheets';
		$config['allowed_types'] = 'gif|jpg|png';
		$config['max_size']	= '0';
		$config['max_width']  = '0';
		$config['max_height']  = '0';
		$config['encrypt_name'] = true;

		$this->load->library('upload', $config);
		
		$this->upload->initialize($config);
		if (! $this->upload->do_upload('image'))
		{
			return array();
		}
		else
		{
			return $this->upload->data();
		}
	}
	
	/**
	 * Crée la vignette d'une image (fonction privée)
	 * @param string $full_path: Chemin local de l'image à envoyer
	 */
	function _create_thumbnail($full_path) {
		$config['image_library'] = 'gd2';
		$config['source_image']	= $full_path;
		$config['new_image'] = './uploads/images/thumbnails/';
		$config['maintain_ratio'] = TRUE;
		$config['width']	 = 150;
		$config['height']	= 100;

		$this->load->library('image_lib'); 
		$this->image_lib->initialize($config);

		if ( ! $this->image_lib->resize())
		{
    		echo $this->image_lib->display_errors();
		}
	}
	
	/**
	 * Fonction qui va gérer les mots clefs d'une fiche lors de l'ajout ou la maj d'une fiche
	 * @param string $tags: Mots clefs au format JSON
	 * @param int $sheet_id: Identifiant de la fiche
	 * @param int $space_id: Identifiant de l'espace actuel
	 */
	function _manage_tags($tags,$sheet_id, $space_id) {		
		$this->load->model('taxonomy');		
		$this->load->model('logqueries');
		
		$input_terms = json_decode($tags);
		$existing_terms = $this->taxonomy->get_tags_of_sheet($sheet_id);
			
		$diff_terms = array_diff_assoc($input_terms,$existing_terms);
		$terms_diff = array_diff_assoc($existing_terms,$input_terms);
		
		if ($diff_terms || $terms_diff) {
			$this->taxonomy->delete($sheet_id);
			
			foreach ($input_terms as $key => $tag) {
				$tag_id = $this->taxonomy->check_tag($tag, $space_id);
				$this->taxonomy->add_taxonomy($sheet_id,$tag_id);
				$log_datas[$key] = $tag_id;
			}
			$log_datas_json = json_encode($log_datas);
			$where = json_encode(array('sheet_id',$sheet_id));
			
			$this->logqueries->removequery($where, 'taxonomy');
			
			$this->logqueries->addquery($space_id, 'UPDATE', 'taxonomy', $log_datas_json, $where);
			
			return true;
			
		} else {
			return false;
		}
	}
}
?>
