<?php
/**
 * Maxcom 
 *
 * Solution opensource pour des personnes presentant des troubles de la communication
 *
 * @author		Maxcom Development Team
 * @copyright	Copyright (c) Association Dynamots.
 * @license		http://www.maxcom.fr/license.html
 * @link		http://www.maxcom.fr
 * @since		Version 1.0
 * @filesource  
 */

// ------------------------------------------------------------------------

/**
 * SuperAdmin Class
 *
 * classe pour gérer l'application
 *
 * @package		Maxcom
 * @category	Controller
 * @author		Maxcom Development Team
 * @link		
 */

class Superadmin extends CI_Controller
{
	/**
	 * Affiche la page d'accueil superadmin
	 */
	function index() {
		if ($this->maxcomutils->checkSessionSuperadmin()) {
			$data = array();
			$this->maxcomutils->load_viewSuperadmin('home', $data, 'Accueil Super Admin');
		}
	}
	
	/**
	 * Récupère les infos globales sur l'instance Max'Com courante:
	 * Nombres d'utilisateurs enregistrés, nombre d'espaces, de fiches...
	 */
	function globalstats() {
		if ($this->maxcomutils->checkSessionSuperadmin()) {
			$this->db->where('active',true);
			$this->db->from('space');
			$data['active_spaces'] = $this->db->count_all_results();
			$data['sheet'] = $this->db->count_all('sheet');
			$data['space'] = $this->db->count_all('space');
			$data['user'] = $this->db->count_all('user');
			$data['category'] = $this->db->count_all('category');
			$data['stat'] = $this->chart();
			
			$this->load->helper('file');
			$thumbnails = get_dir_file_info('uploads/images/thumbnails/', $top_level_only = FALSE);
			$sheets = get_dir_file_info('uploads/images/sheets/', $top_level_only = FALSE);
			$categories = get_dir_file_info('uploads/images/categories/', $top_level_only = FALSE);
			
			$size['thumbs'] = 0;
			$size['sheets'] = 0;
			$size['categories'] = 0;
			
			foreach ($thumbnails as $thumbnail) {
				$size['thumbs'] = $size['thumbs'] + $thumbnail['size'];
			}
			foreach ($categories as $category) {
				$size['categories'] = $size['categories'] + $category['size'];
			}
			foreach ($sheets as $sheet) {
				$size['sheets'] = $size['sheets'] + $sheet['size'];
			}
			$size['thumbs'] = $this->maxcomutils->ByteSize($size['thumbs']);
			$size['categories'] = $this->maxcomutils->ByteSize($size['categories']);
			$size['sheets'] = $this->maxcomutils->ByteSize($size['sheets']);
			
			$data['size'] = $size;
			
			$this->maxcomutils->load_viewSuperadmin('global', $data, 'Statistiques globales');
		}
	}
	
	/**
	 * Affiche la liste des espaces sur l'instance actuelle
	 */
	function list_space() {
		if ($this->maxcomutils->checkSessionSuperadmin()) {
			$data['active_spaces'] = $this->space->get_all();
			$data['inactive_spaces'] = $this->space->get_all(FALSE);
			$this->maxcomutils->load_viewSuperadmin('list_space', $data, 'Espaces Max\'Com');
		}
	}
	
	/**
	 * Affiche les détails d'un espace donné
	 * @param int $id: Identifiant de l'espace à visualiser
	 */
	function detail_space($id) {
		if ($this->maxcomutils->checkSessionSuperadmin()) {
			$data['sheet'] = $this->stats->count('sheet', $id);
			$data['user'] = $this->stats->count('user', $id);
			$data['category'] = $this->stats->count('category', $id);
			$data['space_id'] = $id;
			$data['active'] = $this->space->test_active($id);
			$this->maxcomutils->load_viewSuperadmin('detail', $data, 'Détail de l\'espace');
		}
	}
	
	/**
	 * Passer un espace au statut actif ou inactif
	 * @param int $space_id: Identifiant de l'espace à modifier
	 * @param boolean $active: Activer ou non l'espace
	 */
	function define_active($space_id,$active) {
		if ($this->maxcomutils->checkSessionSuperadmin()) {
			if ($space_id != 1) {
				$this->space->set_active($space_id,$active);
			}
		}
	}
	
	/**
	 * Affiche la vue de confirmation d'un espace
	 * @param int $space_id: Identifiant de l'espace concerné
	 */
	function confirm_delete_space($space_id) {
		if ($this->maxcomutils->checkSessionSuperadmin()) {
			$data['space_id'] = $space_id;
			$this->load->view('superadmin/confirm_delete', $data);
		}
	}
	
	/**
	 * Suppression d'un espace Max'Com
	 * @param int $space_id: Identifiant de l'espace concerné
	 */
	function delete_space($space_id) {
		if ($this->maxcomutils->checkSessionSuperadmin()) {
			$active = $this->space->test_active($space_id);
			if ($active == true || $space_id == 1) {
				$data['title'] = 'Attention!';
				$data['content'] = 'Vous ne pouvez pas supprimer un espace qui est actif';
				$this->maxcomutils->load_viewSuperadmin('alert', $data, 'Attention');
			} else {
				$this->load->model('dbaction');
				$this->load->model('taxonomy');
				$this->load->model('dblogging');
				$this->load->model('captcha');

				$this->sheet->delete_space($space_id);
				//$this->dblogging->delete_space($space_id);
				$this->category->delete_space($space_id);
				$this->dbaction->delete_space($space_id);
				$this->space->delete_space($space_id);
				$this->stats->delete_space($space_id);
				$this->taxonomy->delete_space($space_id);
				$this->user->delete_space($space_id);
				
				//TODO: Supprimer les fichiers relatifs à cet espace?
				$where = json_encode(array('id',$space_id));
				$this->load->model('logqueries');
				$this->logqueries->delete_space($space_id);
				$this->logqueries->addquery($space_id, 'DELETE', 'space', '', $where);
				
				$data['active_spaces'] = $this->space->get_all();
				$data['inactive_spaces'] = $this->space->get_all(FALSE);
				$this->maxcomutils->load_viewSuperadmin('list_space', $data, 'Espaces Max\'Com');
			}
		}
	}
	
	/**
	 * Affiche la page de création d'un nouvel espace
	 */
	function register() {
		if ($this->maxcomutils->checkSessionSuperadmin()) {
			$data = array();
			$this->maxcomutils->load_viewSuperadmin('register', $data, 'Créer un nouvel espace');
		}
	
	}
	
	/**
	 * Enregistrer les stats pour une instance donnée (à faire 1x / jour)
	 * @param string $login: Login de l'utilisateur
	 * @param string $password: Mot de passe encrypté en MD5
	 * @param string $file: Nom du fichier à télécharger en sortie
	 */
	function add_stats($login,$password,$file=NULL) {
		$user_data = $this->user->check($login, $password);
		$datestring = date("Y-m-j");

		if (empty($user_data) || $user_data['id'] != 1) {
			return false;
		} else {
			$spaces = $this->space->get_all();

			foreach ($spaces as $space) {
				$this->load->helper('date');
				$count_sheet = $this->stats->count('sheet', $space['id']);
				$count_category = $this->stats->count('category', $space['id']);
				$data['date'] =  $datestring;
				$data['id'] = '';
				$data['space_id'] = $space['id'];
				$data['sheet'] = $count_sheet;
				$data['user'] = $this->stats->count('user', $space['id']);
				$data['category'] = $count_category;
				$data['published_sheets'] = $this->stats->get_published($space['id']);
				$data['new_sheets'] = '';
				$data['new_categories'] = '';
				
				print_r($data);
				
				$this->stats->insert($data);
				
				$sheet_yesterday = $this->stats->yesterday_count($space['id'],'sheet');
				$category_yesterday = $this->stats->yesterday_count($space['id'],'category');
				
				$data = array();
				$data['new_sheets'] = $count_sheet - $sheet_yesterday;
				$data['new_categories'] = $count_category - $category_yesterday;
				
				$this->stats->update($data,$space['id'],$datestring);
			}
		}
	}
	
	/**
	 * Outil permettant d'exporter la base au format SQL
	 * @param string $login: Login de l'utilisateur
	 * @param string $password: Mot de passe encrypté en MD5
	 * @param string $file: Nom du fichier à télécharger en sortie
	 * @return boolean
	 */
	function export_sql($login,$password,$file='maxcom-sql-backup.gz') {
		$user_data = $this->user->check($login, $password);
		$datestring = date("Y-m-j");

		if (empty($user_data) || $user_data['id'] != 1) {
			return false;
		} else {
			$this->load->dbutil();
			$prefs['tables'] = array('category','comment','dbaction','logging','sheet','space','stats','taxonomy','term','user');

			$backup =& $this->dbutil->backup($prefs);
			
			$this->load->helper('download');
			force_download($file, $backup);
		}
	}
	
	/**
	 * Génération des données à intégrer dans un graphique pour afficher 
	 * l'évolution d'une instance sur les 7 derniers jours 
	 * @return array
	 */
	function chart() {
		if ($this->maxcomutils->checkSessionSuperadmin()) {
			$stats = $this->stats->global_last_stats();
	
			foreach ($stats as $date => $stat) {
				$users[] = $stat['user'];
				$sheets[] = $stat['sheet'];
				$categories[] = $stat['category'];
				$spaces[] = $stat['spaces'];
				$dates[] = $this->maxcomutils->convert_date($date,'daymonth');
			}
			
			$global = array($users, $sheets, $categories, $spaces);
			$maxvalue = max(max($global));
			
			$stat_user = '';
			$stat_sheet = '';
			$stat_category = '';
			$stat_date = '';
			$stat_space = '';
			
			foreach ($dates as $date) {
				$stat_date .= '|'.$date;
			}
			
			foreach ($users as $user) {
				$stat_user .= $user.',';
			}
			$stat_user = substr($stat_user, 0, -1);
		
			foreach ($sheets as $sheet) {
				$stat_sheet .= $sheet.',';
			}
			$stat_sheet = substr($stat_sheet, 0, -1);
		
			foreach ($categories as $category) {
				$stat_category .= $category.',';
			}
			$stat_category = substr($stat_category, 0, -1);
			
			foreach ($spaces as $space) {
				$stat_space .= $space.',';
			}
			$stat_space = substr($stat_space, 0, -1);
			
			$datas['maxvalue'] = $maxvalue;
			$datas['stat_category'] = $stat_category;
			$datas['stat_sheet'] = $stat_sheet;
			$datas['stat_user'] = $stat_user;
			$datas['stat_date'] = $stat_date;
			$datas['stat_space'] = $stat_space;
	
			return $datas;
		}
	}
}
