<?php
/**
 * Maxcom 
 *
 * Solution opensource pour des personnes presentant des troubles de la communication
 *
 * @author		Maxcom Development Team
 * @copyright	Copyright (c) Association Dynamots.
 * @license		http://www.maxcom.fr/license.html
 * @link		http://www.maxcom.fr
 * @since		Version 1.0
 * @filesource  
 */

// ------------------------------------------------------------------------

/**
 * Synchro Class
 *
 * Gere la synchronisation avec les terminaux mobiles 
 *
 * @package		Maxcom
 * @category	Controler
 * @author		Maxcom Development Team
 * @link				
 */

class Synchro extends CI_Controller
{
		
	/**
	 * Fournit les actions à répercuter côté mobile
	 * Exemple d'usage: synchro/get_action/user/pass/2012-10-12/00:00:00
	 * renverra toutes les modifs faites sur l'espace de l'utilisateur user
	 * depuis le 12 octobre 2012 à 00h00
	 * @param string $login: Login de l'utilisateur qui se connecte
	 * @param string $password: Mot de passe de l'utilisateur encrypté en MD5
	 * @param date $date: Date à partir de laquelle on ressort les logs
	 * @param time $time: Heure à partir de laquelle on ressort les logs
	 */
	function get_action($login, $password, $date, $time) {

		$user_data = $this->user->check($login, $password);
		
		$valid_date = preg_match("/^([0-9]{2,4})-([0-1][0-9])-([0-3][0-9])$/", $date);
		$valid_time = preg_match("/^([0-2][0-9]):([0-6][0-9]):([0-6][0-9])$/", $time);
		
		$this->load->library('javascript');
		if (empty($user_data) || !$valid_date || !$valid_time) {
			$result = generate_json(array());
		} else {
			$space_id = $user_data['space_id'];

			$this->load->model('dbaction');
			$dbactions = $this->dbaction->get($space_id, $date, $time);
			
			
			$this->load->helper('date');
			$datestring = "%Y-%m-%d";
			$timestring = "%H:%i:%s";
			$now = time();
			
			$datas['last_sync'] =  mdate($datestring, $now).' '.mdate($timestring, $now);
			$this->space->update($datas,$space_id);

			$result = $this->javascript->generate_json($dbactions, true);
		}
		echo $result;
	}
	
	/**
	 * Fournit les actions à répercuter côté mobile
	 * Exemple d'usage: synchro/get_action/user/pass/2012-10-12/00:00:00
	 * renverra toutes les modifs faites sur l'espace de l'utilisateur user
	 * depuis le 12 octobre 2012 à 00h00
	 * @param string $login: Login de l'utilisateur qui se connecte
	 * @param string $password: Mot de passe de l'utilisateur encrypté en MD5
	 * @param date $date: Date à partir de laquelle on ressort les logs
	 * @param time $time: Heure à partir de laquelle on ressort les logs
	 */
	function show_queries($login, $password, $date, $time) {
	
		$user_data = $this->user->check($login, $password);
	
		$valid_date = preg_match("/^([0-9]{2,4})-([0-1][0-9])-([0-3][0-9])$/", $date);
		$valid_time = preg_match("/^([0-2][0-9]):([0-6][0-9]):([0-6][0-9])$/", $time);
	
		if (empty($user_data) || !$valid_date || !$valid_time) {
			$result = json_encode(array());
		} else {
			$space_id = $user_data['space_id'];
	
			$this->load->model('logqueries');
			$dbactions = $this->logqueries->get($space_id, $date, $time);
			
			foreach ($dbactions as $key => $dbaction) {
				$dbactions[$key]['req_datas'] = json_decode($dbaction['req_datas']);
				$dbactions[$key]['where'] = json_decode($dbaction['where']);
			}

			$this->load->helper('date');
			$datestring = "%Y-%m-%d";
			$timestring = "%H:%i:%s";
			$now = time();
				
			$datas['last_sync'] =  mdate($datestring, $now).' '.mdate($timestring, $now);
			$this->space->update($datas,$space_id);
	
			$result = json_encode($dbactions);
		}
		echo $result;
	}
	
	/**
	 * Fournit l'image d'une fiche
	 * @param string $filename: Nom du fichier image sur le serveur
	 */
	function sheet_image($filename) {
		$prefix = 'uploads/images/sheets';
		$this->output_image($prefix . '/' . $filename);
				
	}
	
	/**
	 * Fournit l'image d'une categorie
	 * @param sting $filename: Nom du fichier image sur le serveur
	 */
	function category_image($filename) {
		$prefix = 'uploads/images/categories';
		$this->output_image($prefix . '/' . $filename);
	}
	
	//TODO: Vérifier si encore utile?
	/**
	 * Fournit le son d'une fiche 
	 * @param string $filename: Nom du fichier son sur le serveur
	 */
	function sheet_sound($filename) {
		$prefix = 'uploads/sounds/sheets';	
		$path = $prefix . "/" . $filename;
		$suffix = end(explode('.', $path));
		switch($suffix) {
			case 'WAV':
			case 'wav':
				$content_type ='Content-type: sound/wav';
				break;
			case 'MP3':
			case 'mp3':
				$content_type ='Content-type: sound/mp3';
				break; 
		}
	
		if (file_exists($path)) {
			$this->output->set_header($content_type);
	  		$this->load->file($path);
		}
		// TODO else
	}	
	
	/**
	 * Fonction auxiliaire gérant la livraison d'image
	 * @param string $path: Chemin de l'image 
	 */
	function output_image($path)  {
		$suffix = strtolower(end(explode('.', $path)));
		$img = null;
		switch($suffix) {
			case 'png':
				$content_type ='Content-type: image/png';
				$img = @imagecreatefrompng($path);
				break;
			case 'jpeg':
			case 'jpg':
				$content_type ='Content-type: image/jpeg';
				$img = @imagecreatefromjpeg($path);
				break; 
			case 'gif':
				$content_type = 'Content-type: image/gif';
				$img = @imagecreatefromgif($path);
				break; 
		}
	
		if (!$img) {
        	$img  = imagecreatetruecolor(150, 30);
        	$bgc = imagecolorallocate($img, 255, 255, 255);
        	$tc  = imagecolorallocate($img, 0, 0, 0);

        	imagefilledrectangle($img, 0, 0, 150, 30, $bgc);

	        imagestring($img, 1, 5, 5, 'Erreur de chargement', $tc);

			$this->output->set_header('Content-type: image/jpeg');
			imagejpeg($img);
			imagedestroy($img);	
    	}	
    	else {
			$this->output->set_header($content_type);
		    switch($suffix) {
				case 'png':
					imagepng($img);
					break;
				case 'jpeg':
				case 'jpg':
					imagejpeg($img);
					break; 
				case 'gif':
					imagegif($img);
					break; 
			}
			imagedestroy($img);	
    	}
	}
	
	function convertdb() {
		header('Content-Type: text/html; charset=utf-8');
		$this->load->library('phpsqlparser');
		$this->load->model('logqueries');
		$this->logqueries->emptytable();
		$this->load->model('dbaction');
		$dbactions = $this->dbaction->getAll();	
		$taxonomy = array();
		
		foreach ($dbactions as $key => $dbaction) {
			$datas = array();
			$query = $this->phpsqlparser->parse($dbaction['query'], TRUE);
			
			$datas['id'] = $dbaction['id'];
			$datas['space_id'] = $dbaction['space_id'];
			$datas['date'] = $dbaction['date'];
			$datas['time'] = $dbaction['time'];
			
			$actions = array_keys($query);
			$datas['req_type'] = $actions[0];
			
			switch ($actions[0]) {
				case 'INSERT': {
					$item_type = substr($query['INSERT']['table'], 1, -1);
					if ($item_type != 'taxonomy') {
						$datas['item_type'] = $item_type;
						$datas['where'] = json_encode(array('id', $query['VALUES'][0]['data'][0]['base_expr']));
							
						switch ($datas['item_type']) {
							case 'term': {
								$term = substr($query['VALUES'][0]['data'][2]['base_expr'], 1, -1);
								$datas['req_datas'] = json_encode(array($term));
							}
							break;

							case 'category': {
								$category_name = substr($query['VALUES'][0]['data'][1]['base_expr'], 1);
								$category_name = substr($category_name, 0, -1);
								$category_datas = array(
										'image' => substr($query['VALUES'][0]['data'][3]['base_expr'], 1, -1),
										'rank' => substr($query['VALUES'][0]['data'][4]['base_expr'], 1, -1),
										'name' => $category_name,
										'parent_id' => substr($query['VALUES'][0]['data'][5]['base_expr'], 1, -1)
								);
								$datas['req_datas'] = json_encode($category_datas);
							}
							break;

							case 'sheet': {
								//$sheet_name = substr($query['VALUES'][0]['data'][1]['base_expr'], 1);
								//$sheet_name = substr($sheet_name, 0, -1);
								foreach ($query['INSERT']['columns'] as $key => $champ) {
									$info = substr($champ['base_expr'], 1, -1);
									$value = $query['VALUES'][0]['data'][$key]['base_expr'];
									$sheet_datas[$info] = ($value[0] == "'") ? substr($value, 1, -1) : $value;
								}
								$sheet_datas['name'] = stripslashes($sheet_datas['name']);
								$datas['req_datas'] = json_encode($sheet_datas);
							}
							break;
						} 
					} else { //On traite les taxonomy à part pour créer un tableau par fiche
						$sheet_id = substr($query['VALUES'][0]['data'][2]['base_expr'], 1, -1);
						$taxonomy_id = substr($query['VALUES'][0]['data'][1]['base_expr'], 1, -1);
						$taxonomy[$sheet_id][] = $taxonomy_id;
					}
				}
				break;
				
				case 'UPDATE': {
					//On ne prend pas en compte les maj de fiches lors de suppression de catégorie (traité en local coté mobile)
					if (substr($query['WHERE'][0]['base_expr'], 1, -1) != 'category_id') {
						$datas['item_type'] = substr($query['UPDATE'][0]['table'], 1, -1);
						$where[0] = substr($query['WHERE'][0]['base_expr'], 1, -1);
						$where[1] = substr($query['WHERE'][2]['base_expr'], 1, -1);
						$datas['where'] = json_encode($where);
						
						$update_datas = array();
						
						foreach ($query['SET'] as $update_key => $update_value) {
							$update_data_key = substr($update_value['sub_tree'][0]['base_expr'], 1, -1);
							$update_data_value = $update_value['sub_tree'][2]['base_expr'];
							$update_datas[$update_data_key] = ($update_data_value[0] == "'") ? substr($update_data_value, 1, -1) : $update_data_value;
						}
						$update_datas['name'] = stripslashes($update_datas['name']);
						$datas['req_datas'] = json_encode($update_datas);
					}
				}
				break;
				
				case 'DELETE':
					if (str_replace("`", "", $query['FROM'][0]['table']) != 'taxonomy') {
						$datas['item_type'] = substr($query['FROM'][0]['table'], 1, -1);
						$where[0] = substr($query['WHERE'][0]['base_expr'], 1, -1);
						$where[1] = substr($query['WHERE'][2]['base_expr'], 1, -1);
						$datas['where'] = json_encode($where);
					}
				break;
			}
			if (array_key_exists('item_type', $datas)) {
				$this->logqueries->addtranslate($datas);
				echo '<pre>';
				echo 'Requete de base:';
				print_r($dbaction);
				echo '<br />Requete convertie:';
				print_r($datas);
				//print_r($query);
				echo '</pre><hr>';
			}
		}
		foreach ($taxonomy as $sheet_id => $taxonomys) {
			$donnes['id'] = '';
			$donnes['space_id'] = $this->sheet->get_space_id($sheet_id);
			$donnes['date'] = date('Y-m-d');
			$donnes['time'] = date('H:i:s');
			$donnes['req_type'] = 'UPDATE';
			$donnes['req_datas'] = json_encode(array_values(array_unique($taxonomys)));
			$donnes['item_type'] = 'taxonomy';
			$donnes['where'] = json_encode(array('sheet_id',$sheet_id));
			
			$this->logqueries->addtranslate($donnes);
			echo '<pre>';
			 print_r($donnes);
			//print_r($dbaction['query']);
			//print_r($query);
			echo '</pre><hr>';
		}
	}
}
?>
