<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed'); 

class Maxcomutils {

	/**
	 * Charge les différentes vues de la page pour l'interface d'admin
	 * @param string $view_name: Vue à afficher
	 * @param array $view_data: Données à afficher dans la vue
	 */
	function load_view($view_name, $view_data) {
		$CI =& get_instance();
		
		$CI->load->helper('url');
		$CI->load->library('session');
		
		$header_data = array('user_space_role' => $CI->session->userdata('user_space_role'),'user_id' => $CI->session->userdata('user_id'));
		$CI->load->view('shared/header', $header_data);	
		$CI->load->view('shared/menu');
		$CI->load->view($view_name, $view_data); 
		$CI->load->view('shared/footer');
	}
	
	/**
	 * Charge les différentes vues de l'interface utilisateur
	 * @param string $view_name: Nom de la vue à afficher
	 * @param array $view_data: Données à afficher dans la vue
	 */
	function load_viewHome($view_name, $view_data) {
		$CI =& get_instance();
	
		$CI->load->helper('url');
		$CI->load->library('session');
	
		$header_data = array('user_space_role' => $CI->session->userdata('user_space_role'),'user_id' => $CI->session->userdata('user_id'));
		$CI->load->view('shared/header', $header_data);
		$CI->load->view($view_name, $view_data);
		$CI->load->view('shared/footer');
	}
	
	/**
	 * Charge la vue pour les pages qui s'affichent en popup
	 * @param string $view_name: Nom de la vue popup à afficher
	 * @param array $view_data: Données à afficher dans la vue 
	 */
	function load_viewPopup($view_name, $view_data) {
		$CI =& get_instance();
	
		$CI->load->helper('url');
		$CI->load->library('session');
		
		$header_data = array('user_space_role' => $CI->session->userdata('user_space_role'),'user_id' => $CI->session->userdata('user_id'));
		$CI->load->view('shared/header', $header_data);
		$CI->load->view($view_name, $view_data);
		$CI->load->view('shared/footer-popup');
	}

	/**
	 * Charge la vue pour les pages superadmin
	 * @param string $view_name: Nom de la vue super admin à afficher
	 * @param unknown_type $view_data
	 * @param unknown_type $header
	 */
	function load_viewSuperadmin($view_name, $view_data, $header) {
		$CI =& get_instance();
	
		$CI->load->helper('url');
		$CI->load->library('session');
	
		$header_data = array('user_space_role' => $CI->session->userdata('user_space_role'),'user_id' => $CI->session->userdata('user_id'));
		$header_data['page_title'] = $header;
		$CI->load->view('superadmin/header', $header_data);
		$CI->load->view('superadmin/'.$view_name, $view_data);
		$CI->load->view('superadmin/footer');
	}
	
	/**
	 * Créé une session utilisateur
	 * @param int $user_id: Identifiant de l'utilisateur actuel
	 * @param int $space_id: Identifiant de l'espace actuel
	 * @param string $user_space_role: Rôle de l'utilisateur actuel
	 * @param string $user_name: Nom de l'utilisateur actuel
	 * @param string $space_name: Nom de l'espace actuel
	 * @param int $sessionduration: Durée de la session en secondes
	 */
	function createSession($user_id,$space_id,$user_space_role,$user_name,$space_name,$sessionduration) {
		$CI =& get_instance();
	
		$CI->load->helper('url');
		$CI->load->library('session');
		
		$CI->session->set_userdata('user_id', $user_id);
		$CI->session->set_userdata('user_name', $user_name);
		$CI->session->set_userdata('space_id', $space_id);
		$CI->session->set_userdata('user_space_role', $user_space_role);
		$CI->session->set_userdata('user_space_name', $space_name);
	}
	
	/**
	 * Vérifie Si une session utilisateur existe
	 * @return boolean
	 */
	function checkSession() {
		$CI =& get_instance();
		
		$CI->load->helper('url');
		$CI->load->library('session');
		$CI->load->model('space');
		
		$datas['user_space_role'] = 'none';
		$view_datas['error'] = '';
		
		$userid = $CI->session->userdata('user_id');
		$space_id = $CI->session->userdata('space_id');
		
		$space_active = $CI->space->test_active($space_id);
		
		if (!$space_active) {
			$view_datas['error'] = 'Votre espace Max\'Com est désactivé';
		} 
		
		if (empty($userid) || !$space_active) {
			$CI->load->view('shared/header');
			$CI->load->view('login',$view_datas);
			$CI->load->view('shared/footer',$datas);
			return false;
		}
		else {
			return true;
		}
	}
	
	/**
	 * Vérifie si l'utilisateur connecté est superadmin
	 * @return boolean
	 */
	function checkSessionSuperadmin() {
		$CI =& get_instance();
		
		$CI->load->helper('url');
		$CI->load->library('session');
		
		$userid = $CI->session->userdata('user_id');
		if (empty($userid)) {
			redirect('home', 'refresh');
			return false;
		}
		elseif ($userid != 1) {
			redirect('home', 'refresh');
			return false;
		}
		else {
			return true;
		}
	}
	
	/**
	 * Permet de convertir une date format mysql au format standard
	 * @param date $date: Date au format MySQL
	 * @param string $out: Type de format en sortie (datetime, date, daymonth)
	 * @return string
	 */
	function convert_date($date,$out='datetime') {
		$CI =& get_instance();
		$CI->load->helper('date');
		
		if ($out == 'datetime') {
			$datestring = "%d/%m/%Y - %Hh%im%ss";
		} elseif ($out == 'date') {
			$datestring = "%d/%m/%Y";
		} elseif ($out == 'daymonth') {
			$datestring = "%d/%m";
		}
		
		$unix = mysql_to_unix($date);
		return mdate($datestring,$unix);
	}

	/**
	 * Permet de convertir des octets en une valeur compréhensible
	 * @param int $bytes: Valeur à convertir en Octets
	 * @return string $size: Valeur convertie
	 */
	function ByteSize($bytes)  { 
		$size = $bytes / 1024; 
		if($size < 1024) { 
			$size = number_format($size, 2); 
			$size .= ' Ko'; 
		} else { 
			if($size / 1024 < 1024) { 
			    $size = number_format($size / 1024, 2); 
			    $size .= ' Mo'; 
			} else if ($size / 1024 / 1024 < 1024) { 
				    $size = number_format($size / 1024 / 1024, 2); 
				    $size .= ' Go'; 
			}  
		} 
		return $size; 
	} 
	
	/**
	 * Vérifie si un utilisateur a bien les droits pour effectuer une action:
	 * - Soit il est superadmin (tous les droits partout)
	 * - Soit il est admin de l'espace actuel
	 * - Soit il est rédacteur et l'item lui appartient bien
	 * Cette fonction est appelée par exemple pour vérifier qu'un utilisateur peut 
	 * modifier une fiche. On vérifie alors que l'utilisateur satisfait à cette fonction.
	 * @param int $space_id: Identifiant de l'espace à vérifier
	 * @param int $user_id: Identifiant de l'utilisateur à vérifier
	 * @return boolean
	 */
	function checkUserRights($space_id,$user_id){
		$CI =& get_instance();
		
		$CI->load->library('session');
		$user = array();
		
		$user["id"]	= $CI->session->userdata("user_id");
		$user["role"] = $CI->session->userdata("user_space_role");
		$user["space"] = $CI->session->userdata("space_id");
		if(
			($user["role"]=="administrateur")&&($user["space"]==$space_id)||
			($user["role"]=="redacteur")&&($user["space"]==$space_id)&&($user["id"]==$user_id)||
			($user["id"]==1)
			){
				return true;
			}else{
				return false;
			}

	}
	
	function createCaptcha(){
		$CI =& get_instance();
		$CI->load->helper('captcha');
	
		$vals = array(
				'img_path' => './captcha/',
				'img_url' => base_url()."captcha/",
				'img_width' => 120,
				'img_height' => 30,
				'expiration' => 7200
		);
	
		$cap = create_captcha($vals);
	
		return $cap;
	}
}
