<?php
/**
 * Maxcom 
 *
 * Solution opensource pour des personnes presentant des troubles de la communication
 *
 * @author		Maxcom Development Team
 * @copyright	Copyright (c) Association Dynamots.
 * @license		http://www.maxcom.fr/license.html
 * @link		http://www.maxcom.fr
 * @since		Version 1.0
 * @filesource  
 */

// ------------------------------------------------------------------------

/**
 * Category Class
 *
 * Gere les categories
 *
 * @package		Maxcom
 * @category	Model
 * @author		Maxcom Development Team
 * @link		
 */

require_once('synchronized.php');

class Category extends SynchronizedEntity {

	/*
	 * Récupère l'id de la première catégorie (classée par note...)
	 */
	function get_first($space_id) {
		$this->db->where('space_id', $space_id);
		$this->db->order_by('rank', 'DESC');
		$this->db->limit(1);
		$query = $this->db->get('category');
		return $query->row_array();
	}
	
	/**
	 * retourne toutes les categories d'un spacee
	 * 
	 */
	function get_all($space_id = '') {
		if (!empty($space_id)) {
			$this->db->where('space_id', $space_id);
		}
		$this->db->order_by('rank', "DESC");
    	$query= $this->db->get('category');

		if($query->num_rows() > 0) {
			foreach ($query->result() as $row) {
			    $categories[] = $row;
			}
			return $categories;
		} else {
			return array();
		}
	}
	
	/**
	 * retourne la categorie correspondant à un id
	 * 
	 */
	function get($category_id) {	
		$this->db->where('id', $category_id);
    	$query= $this->db->get('category');

		if($query->num_rows() > 0) {
			return $query->row_array();
		} else {
			return array();	
		}
	}
	
	/**
	* retourne le nom de la categorie correspondant à un id
	*
	*/
	function get_name($category_id) {
		$this->db->where('id', $category_id);
		$query= $this->db->get('category');
		if($query->num_rows() > 0) {
			$row = $query->row();
			return $row->name;
		}
		else {
			return "Aucune";
		}
	}
	
	/**
	 * retourne le nombre de categorie correspondant à un spacee
	 * 
	 */
	function get_number($space_id) {
		$this->db->where('space_id', $id);
		return $this->db-> count_all_results('category');
	}
	
	
	/**
	 * creation d'une nouvelle categorie 
	 * 
	 */
	
	function create($data) 
	{
		// recuperation max id
		$this->db->select_max('id');
		$query = $this->db->get('category');
		
		$id = $query->row()->id;
		if (empty($id)) {
			$id = 1;
		}  else {
			$id = $id + 1;
		}
		$space_id = $data['space_id'];	
	
		$data['id'] = $id;	
		$insert = $this->db->insert('category', $data);
		
		if  ( $insert === false ) {
			show_error('Category creation error' );
		} else {
			$query = $this->db->last_query();
			$this->log_dbaction($space_id, $query);
		}	
		
		return $id;
	}
	
	function search($datas,$space_id) {
		if (!empty($space_id)) {
			$this->db->where('space_id', $space_id);
		}
		$this->db->like('name', $datas);
		$this->db->order_by('rank', "DESC");
		$query= $this->db->get('category');
		
		if($query->num_rows() > 0) {
			foreach ($query->result() as $row) {
				$categories[] = $row;
			}
			return $categories;
		} else {
			return array();
		}
	}
	
	
	/**
	 * mise à jour d'une categorie 
	 * 
	 */
	function update($data) 
	{
		$space_id = $data['space_id'];	
		
		$this->db->where('id', $data['id']);
		$this->db->update('category', $data);
		
		$query = $this->db->last_query();
		$this->log_dbaction($space_id, $query);
	}
	
	
	function delete($id) {	
		$category_data = $this->get($id);
		$space_id = $category_data['space_id'];
		
		$this->db->where('id', $id);
		$this->db->delete('category');
		
		$query = $this->db->last_query();
		$this->log_dbaction($space_id, $query);
		
		$data_sheet['category_id'] = 0;
		$this->db->where('category_id', $id);
		$this->db->update('sheet', $data_sheet);
		
		$query = $this->db->last_query();
		$this->log_dbaction($space_id, $query);
		
		$data_category['parent_id'] = 0;
		$this->db->where('parent_id', $id);
		$this->db->update('category', $data_category);
		
		$query = $this->db->last_query();
		$this->log_dbaction($space_id, $query);
	}
	
	function ten_last_modif($space_id) {
		$this->db->where('category.space_id',$space_id);
		$this->db->limit(10);
		$this->db->select('category.id,category.author_id,category.name,user.firstname as author_name,user.lastname as author_lastname');
		$this->db->join('user','user.id = category.author_id','left outer');
		$this->db->order_by("category.last_modif", "desc"); 
		$query = $this->db->get('category');
		
		if ($query->num_rows() > 0) {
			return $query->result_array();
		} else {
			return array();
		}
		
	}
	
	function delete_space($space_id) {
		$this->db->where('space_id',$space_id);
		$this->db->delete('category');
	}
}
