<?php
/**
 * Maxcom 
 *
 * Solution opensource pour des personnes presentant des troubles de la communication
 *
 * @author		Maxcom Development Team
 * @copyright	Copyright (c) Association Dynamots.
 * @license		http://www.maxcom.fr/license.html
 * @link		http://www.maxcom.fr
 * @since		Version 1.0
 * @filesource  
 */

// ------------------------------------------------------------------------

/**
 * LogQueries Class
 *
 * Gere les actions de synchronisation (nouvelle version)
 *
 * @package		Maxcom
 * @category	Model
 * @author		Maxcom Development Team
 * @link		
 */

class LogQueries extends CI_Model {
	
	/**
	 * Récupère toutes les actions correspondant à un espace depuis une date donnée
	 * @param int $space_id: Identifiant de l'espace concerné
	 * @param date $date: Date à partir de laquelle on ressort les logs
	 * @param time $time: Heure à partir de laquelle on ressort les logs
	 * @return multitype:
	 */
	function get($space_id, $date, $time) {
		$this->db->where('space_id', $space_id);
		$date_sup = "(date > '".$date."')";		
		$date_eq = "(date = '".$date."') AND (time > '".$time."')";
		$date_expr = "(".$date_sup." OR (".$date_eq."))";
		
		$this->db->order_by("id", "asc"); 
		$this->db->where($date_expr);
		$query =  $this->db->get('logqueries');
		
		if ($query->num_rows() > 0) {
			return $query->result_array();
		}
		else {
			return array();
		}
	}
		
	/**
	 * Ajout d'une requête dans la table logqueries
	 * @param int $space_id: Identifiant de l'espace concerné
	 * @param string $req_type: Type de requête (INSERT, UPDATE, DELETE)
	 * @param string $item_type: Type de donnée ajoutée (Sheet, Category, Term, Taxonomy)
	 * @param int $item_id: Identifiant de l'item sur lequel la requête est jouée
	 * @param string $datas: Données ajoutées au format JSON
	 * @param string $where: Dans le cas où une requête touche plusieurs item
	 * @return int : Identifiant de l'insertion  
	 */
	function addquery($space_id, $req_type, $item_type, $datas='', $where='') {	
		$this->load->helper('date');
		$datestring = "%Y-%m-%d";
		$timestring = "%H:%i:%s";
		$now = time();
		
		$data = array(
				'id' => '',
				'space_id' => $space_id,
				'req_type' => $req_type,
				'item_type' => $item_type,
				'date' => mdate($datestring, $now),
				'time' => mdate($timestring, $now),
				'req_datas' => $datas,
				'where' => $where
		);
		
		$insert = $this->db->insert('logqueries', $data);
		
		if  ( $insert === false ) {
			show_error('Dbaction creation error' );
		} else {
			return $this->db->insert_id() ;
		}
	}
	
	function addtranslate($datas) {
		$this->db->insert('logqueries', $datas);
	}
	
	function emptytable() {
		$this->db->empty_table('logqueries');
	}
	
	/**
	 * Supprime une requête dans la table logqueries selon la clause where et le type d'item défini
	 * @param string $where: Clause where encodée en tableau au format JSON
	 * @param string $item_type: Type de l'item à supprimer
	 */
	function removequery($where,$item_type) {
		$this->db->where('where', $where);
		$this->db->where('item_type', $item_type);
		$this->db->delete('logqueries');		
	}

	/**
	 * supprime les actions d'un espace
	 * @param int $space_id: Identifiant de l'espace supprimé
	 */	
	function delete_space($space_id) {
		$this->db->where('space_id',$space_id);
		$this->db->delete('logqueries');
	}	
}
?>
