<?php 

/**
 * Maxcom 
 *
 * Solution opensource pour des personnes presentant des troubles de la communication
 *
 * @author		Maxcom Development Team
 * @copyright	Copyright (c) Association Dynamots.
 * @license		http://www.maxcom.fr/license.html
 * @link		http://www.maxcom.fr
 * @since		Version 1.0
 * @filesource  
 */

// ------------------------------------------------------------------------

/**
 * Sheet Class
 *
 * Gere les fiches
 *
 * @package		Maxcom
 * @category	Model
 * @author		Maxcom Development Team
 * @link		
 */
require_once('synchronized.php');

class Sheet extends SynchronizedEntity {
	
	
	/**
	 * comptage du nombre de fiche 
	 * 
	 */
	function count($name = '') {
	    if ( $name === '') {
	    	$this->db->like('name', $name);
	    }
	  	$query= $this->select();
		return $query->num_rows(); 
	}	
	
	/**
	 * retourne les données d'une fiche selon un id
	 * 
	 */
	function get($sheet_id) {	
		$this->db->where('id', $sheet_id);
    	$query= $this->db->get('sheet');

		if($query->num_rows() > 0) {
			return $query->row_array();
		} else {
			return array();	
		}
	}
	
	function get_space_id($sheet_id) {
		$sheet_data = $this->get($sheet_id);
		$space_id = $sheet_data['space_id'];
		return $space_id;	
	}
	
	/**
	 * 
	* retourne le nombre de fiches dans une catégorie
	*
	*/
	function get_number_incategory($category_id) {
		$this->db->where('category_id', $category_id);
		$this->db->from('sheet');
		return $this->db->count_all_results();
	}
	
	/**
	 * retourne les données d'une ou des fiches selon un nom et un spacee
	 * 
	 */
	function get_by_name($name, $space) {
		$query = $this->db->get_where('sheet', "name LIKE".$name." AND space=".$space);
		
		if($query->num_rows() > 0) {
			foreach ($query->result() as $row) {
			    $sheets[] = $row;
			}
		}
		return $sheets;
	}
	
	/**
	 * retourne les données de toutes les fiches
	 * 
	 */
	function get_all($space_id = '') {
		if (!empty($space_id)) {
			$this->db->where('sheet.space_id', $space_id);
		}
		$this->db->select('sheet.id,sheet.author_id,sheet.name,sheet.image,favorite,status,nbclics,sheet.category_id,sheet.space_id,note,category.name as category_name,user.firstname as author_name,user.lastname as author_lastname');
		$this->db->join('category','category.id = sheet.category_id','left outer');
		$this->db->join('user','user.id = sheet.author_id','left outer');
		$this->db->order_by('note', 'DESC');
    	$query = $this->db->get('sheet');

		if($query->num_rows() > 0) {
			foreach ($query->result() as $row) {
			    $sheets[] = $row;
			}
			return $sheets;
		} else {
			return array();
		}
		
	}
	
	/*
	 * Renvoie toutes les fiches publiées d'une catégorie
	 */
	function get_published($category_id,$space_id) {
		$where = "(`space_id` = $space_id AND `category_id` = $category_id AND `status` = 1) OR (`space_id` = $space_id AND `category_id` = $category_id AND `status` = 2)";
		$this->db->where($where);
		$this->db->select('id,name,image');
		$this->db->order_by('note', 'DESC');
		$this->db->order_by('nbclics', 'DESC');
		$this->db->order_by('date', 'DESC');
		
		$query = $this->db->get('sheet');
	
		if($query->num_rows() > 0) {
			foreach ($query->result() as $row) {
				$sheets[] = $row;
			}
			return $sheets;
		} else {
			return array();
		}
	}
	
	/**
	 * 
	 * retourne la note d'une fiche selon un id
	 * 
	 */
	function get_note($id) {
		$sheet = $this->get($id);
		return $sheet['note'];
	}
	
	
	/**
	 * retourne les fiches favorites du spacee
	 */
	function get_favorite($space_id) {
		$this->db->where('favorite', 1);
		$this->db->where('space_id', $space_id);
    	$this->db->order_by('note', 'DESC');
    	$query = $this->db->get('sheet');

		if($query->num_rows() > 0) {
			foreach ($query->result() as $row) {
			    $sheets[] = $row;
			}
			return $sheets;
		} else {
			return array();			
		}
	}
	
	/*
	 * Retourne les fiches favorites publiées uniquement
	 */
	function get_favorite_published($space_id) {
		$this->db->where('favorite', 1);
		$this->db->where('space_id', $space_id);
		$this->db->where('status', 1);
		$this->db->or_where('status', 2);
		$this->db->order_by('note', 'DESC');
		$query = $this->db->get('sheet');
	
		if($query->num_rows() > 0) {
			foreach ($query->result() as $row) {
				$sheets[] = $row;
			}
			return $sheets;
		} else {
			return array();
		}
	}
	
	/**
	 * création d'une nouvelle fiche 
	 * 
	 */
	
	function create($data) 
	{
		// recuperation max id
		$this->db->select_max('id');
		$query = $this->db->get('sheet');
		
		$id = $query->row()->id;
		if (empty($id)) {
			$id = 1;
		}  else {
			$id = $id + 1;
		}
		$space_id = $data['space_id'];	
	
		$data['id'] = $id;	
		$insert = $this->db->insert('sheet', $data);
	
		if  ( $insert === false ) {
			show_error('Sheet creation error' );
		} else {
			$query = $this->db->last_query();
			$this->log_dbaction($space_id, $query);
			
			$this->db->select('id');
			$this->db->where('date',$data['date']);
			$this->db->where('author_id',$data['author_id']);
			$query = $this->db->get('sheet');
			
			$result = $query->row_array();
			return $id;
		}	
	}
	
	function search($datas,$space_id) {
		if (!empty($space_id)) {
			$this->db->where('sheet.space_id', $space_id);
		}
		$this->db->like('sheet.name', $datas);
		$this->db->select('sheet.id,sheet.author_id,sheet.name,sheet.image,favorite,status,nbclics,sheet.category_id,sheet.space_id,note,category.name as category_name,user.firstname as author_name,user.lastname as author_lastname');
		$this->db->join('category','category.id = sheet.category_id','left outer');
		$this->db->join('user','user.id = sheet.author_id','left outer');
		$this->db->order_by('note', 'DESC');
    	$query = $this->db->get('sheet');
		
		if($query->num_rows() > 0) {
			foreach ($query->result() as $row) {
				$sheets[] = $row;
			}
			return $sheets;
		} else {
			return array();
		}
	}
	
	/*
	 * Fonction de filtre des catégories pour l'administration
	 */
	function filter($category_id,$space_id) {
		if (!empty($space_id)) {
			$this->db->where('sheet.space_id', $space_id);
		}
		$this->db->where('sheet.category_id', $category_id);
		$this->db->select('sheet.id,sheet.author_id,sheet.name,sheet.image,favorite,status,nbclics,sheet.category_id,sheet.space_id,note,category.name as category_name,user.firstname as author_name,user.lastname as author_lastname');
		$this->db->join('category','category.id = sheet.category_id','left outer');
		$this->db->join('user','user.id = sheet.author_id','left outer');
		$this->db->order_by('note', 'DESC');
		$query = $this->db->get('sheet');
						
		if($query->num_rows() > 0) {
			foreach ($query->result() as $row) {
				$sheets[] = $row;
			}
			return $sheets;
		} else {
			return array();
		}
	}
	
	/**
	 * mise à jour d'une fiche 
	 * 
	 */
	function update($data) 
	{
		$space_id = $data['space_id'];
		
		$this->db->where('id', $data['id']);
		$this->db->update('sheet', $data);

		$query = $this->db->last_query();				
		$this->log_dbaction($space_id, $query);
	}
	
	/**
	 * mise a jour du nombre de clics d'une fiche  
	 */
	function update_clicks($id, $increment) 
	{
		$sheet = $this->get($id);
		
		if (!empty($sheet)) {
			$nbClick = $sheet['nbclics'];
					
			$data =  array();
			$data['id'] = $id;
			$data['nbclics'] = $nbClick + $increment;

			// on ne reutilise pas update car on ne veut pas 
			// de synchro sur le nombre de clics			
			$this->db->where('id', $data['id']);
			$this->db->update('sheet', $data);		
		}
	}
	
	
	/**
	 * suppression d'une fiche 
	 * 
	 */
	function delete($id) {	
		$space_id = $this->get_space_id($id);
		
		$this->db->where('id', $id);
		$this->db->delete('sheet');		

		$query = $this->db->last_query();
		$this->log_dbaction($space_id, $query); 
	}
	
	
	function ten_last_modif($space_id) {
		$this->db->where('sheet.space_id',$space_id);
		$this->db->limit(10);
		$this->db->select('sheet.id,sheet.author_id,sheet.name,user.firstname as author_name,user.lastname as author_lastname');
		$this->db->join('user','user.id = sheet.author_id','left outer');
		$this->db->order_by("sheet.last_modif", "desc"); 
		$query = $this->db->get('sheet');
		
		if ($query->num_rows() > 0) {
			return $query->result_array();
		} else {
			return array();
		}
		
	}
	
	function delete_space($space_id) {
		$this->db->where('space_id',$space_id);
		$this->db->delete('sheet');
	}
}

?>
