<?php
/**
 * Maxcom 
 *
 * Solution opensource pour des personnes presentant des troubles de la communication
 *
 * @author		Maxcom Development Team
 * @copyright	Copyright (c) Association Dynamots.
 * @license		http://www.maxcom.fr/license.html
 * @link		http://www.maxcom.fr
 * @since		Version 1.0
 * @filesource  
 */

// ------------------------------------------------------------------------

/**
 * Taxonomy Class
 *
 * Gere les classifications
 *
 * @package		Maxcom
 * @category	Model
 * @author		Maxcom Development Team
 * @link		
 */
require_once('synchronized.php');

class Taxonomy extends SynchronizedEntity {
	
	/**
	* Renvoie les tags associés à un espace donné
	*/
	function get_tags($space_id) {
		$this->db->where('space_id',$space_id);
		$this->db->select('name');
		$query = $this->db->get('term');
		
		if ($query->num_rows() > 0) {
			return $query->result_array();
		} else {
			return array();
		}
	}
	
	/**
	* Renvoie les tags associés à une fiche donnée (encodé au format json)
	*/
	function get_tags_of_sheet($sheet_id) {
		$this->db->where('sheet_id',$sheet_id);
		$this->db->from('taxonomy');
		$this->db->select('taxonomy.term_id, term.name as name');
		$this->db->join('term','term.id = taxonomy.term_id','left outer');
		$query = $this->db->get();
			
		if ($query->num_rows() > 0) {
			$tags = $query->result_array();
			foreach ($tags as $tag) {
				$result[] = $tag['name'];
			} 
			return $result;
		} else {
			return array();
		}
	}
	
	/**
	* Vérifie si un tag existe dans la table term, sinon on le créé
	* et retourne l'id de ce tag
	*/
	function check_tag($tag, $space_id) {
		$this->db->select('id');
		$this->db->where('name',$tag);
		$query = $this->db->get('term');
		
		if ($query->num_rows() > 0) {
			$result = $query->row_array();
			return $result['id'];
		} else {
			$this->db->select_max('id');
			$query = $this->db->get('term');
		
			$id = $query->row()->id;
			if (empty($id)) {
				$id = 1;
			}  else {
				$id = $id + 1;
			}
			$datas = array('id' => $id, 'space_id' => $space_id, 'name' => $tag);
			$this->db->insert('term', $datas);			
			
			//Insertion dans logqueries:
			$log_datas_json = json_encode(array($tag));
			$where = json_encode(array('id',$id));
			$this->logqueries->addquery($space_id, 'INSERT', 'term', $log_datas_json, $where);
			
			$query = $this->db->last_query();
			$tag_id = $this->db->insert_id();
			$this->log_dbaction($space_id, $query);
			
			return $id;
		}
	}
	
	/**
	* Ajoute une relation entre un tag et une fiche dans la table taxonomy
	*/
	function add_taxonomy($sheet_id,$tag_id) {
		
		$space_id = $this->sheet->get_space_id($sheet_id);
		
		$datas = array('category_id' => NULL, 'term_id' => $tag_id, 'sheet_id' => $sheet_id);
		$this->db->insert('taxonomy', $datas);
				
		$query = $this->db->last_query();
		$this->log_dbaction($space_id, $query);
	}
	
	/**
	* Supprime les relations entre tag et fiche dans la table taxonomy
	*/
	function delete($sheet_id) {		
		
		$space_id = $this->sheet->get_space_id($sheet_id);
		
		$this->db->where('sheet_id', $sheet_id);
		$this->db->delete('taxonomy');
		
		$query = $this->db->last_query();
		$this->log_dbaction($space_id, $query);
	}	
	
	/**
	 * Supprime toutes les relations de la table taxonomie pour un espace donné
	 * @param int $space_id
	 */
	function delete_space($space_id) {
		$this->db->where('space_id',$space_id);
		$query = $this->db->get('term');
		if ($query->num_rows() > 0) {
			$terms = $query->result_array();
			foreach ($terms as $term) {
				$this->delete($term['id']);
			}
			$this->db->where('space_id',$space_id);
			$this->db->delete('term');
		}
	}
}
?>
