<?php

/**
 * Maxcom 
 *
 * Solution opensource pour des personnes presentant des troubles de la communication
 *
 * @author		Maxcom Development Team
 * @copyright	Copyright (c) Association Dynamots.
 * @license		http://www.maxcom.fr/license.html
 * @link		http://www.maxcom.fr
 * @since		Version 1.0
 * @filesource  
 */

// ------------------------------------------------------------------------

/**
 * User Class
 *
 * Gere les utilisateurs dans la base de donnees
 *
 * @package		Maxcom
 * @category	Model
 * @author		Maxcom Development Team
 * @link		
 */

class User extends CI_Model
{
	
	function get_all($space_id = '') {
		if (!empty($space_id)) {
			$this->db->where('space_id', $space_id);
			$this->db->where('space_role !=','utilisateur');
		} 
		$query = $this->db->get('user');

		if($query->num_rows() > 0) {
			foreach ($query->result() as $row) {
			    $data[] = $row;
			}
			return $data;
		}
		else {
			return array();
		}
	}
	
	/*
	 * Vérifie si un nom d'utilisateur est déjà pris
	 */
	function exist($login) 
	{
		$where = $this->db->get_where('user', array('login' => $login));
		return $where->num_rows() > 0;
	}
	
	/*
	* 
	* retourne les données d'un utilisateur selon un id
	*
	*/
	function get($user_id) {
		$this->db->where('id', $user_id);
		$query= $this->db->get('user');
	
		if($query->num_rows() > 0) {
			return $query->row_array();
		} else {
			return array();
		}
	}
	
/*
	* 
	* retourne les données d'un utilisateur selon un login
	*
	*/
	function getwithLogin($login) {
		$this->db->where('login', $login);
		$query= $this->db->get('user');
	
		if($query->num_rows() > 0) {
			return $query->row_array();
		} else {
			return array();
		}
	}
	
	/*
	* 
	* Retourne l'utilisateur mobile d'un spacee
	*
	*/
	function get_mobile_user($space_id) {
		$this->db->where('space_id',$space_id);
		$this->db->where('space_role','utilisateur');
		$this->db->limit(1);
		$query= $this->db->get('user');
	
		if($query->num_rows() > 0) {
			return $query->row_array();
		} else {
			return array();
		}
	}
	
	/*
	* retourne le nom de l'utilisateur correspondant à un id
	*
	*/
	function get_name($user_id) {
		$this->db->where('id', $user_id);
		$query= $this->db->get('user');
		if($query->num_rows() > 0) {
			$row = $query->row();
			return $row->firstname." ".$row->lastname;
		}
	}
	
	/*
	 * Retourne toutes les infos d'un user en fonction d'un critère
	 * de recherche basé sur le login
	 */
	function search($datas,$space_id) {
		if (!empty($space_id)) {
			$this->db->where('space_id', $space_id);
		}
		$this->db->like('login', $datas);
		$this->db->or_like('firstname', $datas);
		$this->db->or_like('lastname', $datas);
		$this->db->or_like('mail', $datas);
		$this->db->order_by('space_role', "DESC");
		$query= $this->db->get('user');
	
		if($query->num_rows() > 0) {
			foreach ($query->result() as $row) {
				$users[] = $row;
			}
			return $users;
		} else {
			return array();
		}
	}
	
	/*
	 * Crée un nouvel utilisateur dans la base
	 */
	function create($data) 
	{
		$insert = $this->db->insert('user', $data);
		
		if  ( $insert === false ) {
			show_error('User creation error' );
		} else {
			return $this->db->insert_id() ;
		}
	}
	
	/*
	 * Met à jour l'utilisateur dans la base
	 */
	function update($data) 
	{
		$this->db->where('id', $data['id']);
		$this->db->update('user', $data);
	}
	
	/*
	 * Supprime l'utilisateur de la base en fonction de son id
	 */
	function delete($id) 
	{
		$this->db->where('id', $id);
		$this->db->delete('user');
	}	
	
	/*
	 * Retourne le nombre d'utilisateurs dans un spacee
	 */
	function count($space_id) {
		$this->db->where('space_id', $space_id);
		return $this->db->count_all_results('user');
	}
	
	/*
	 * retourne les infos de l'utilisateur si le login
	 * et le mot de passe sont corrects
	 */
	function check($login, $password) 
	{	
		$this->db->where('login', $login);
		$this->db->where('password', $password);
    		$query = $this->db->get('user');

		if($query->num_rows() > 0) {
			return $query->row_array();
		} else {
			return array();			
		}
	}
	
	function get_admin($space_id) {
		$this->db->where('space_id',$space_id);
		$this->db->where('space_role','administrateur');
		$query = $this->db->get('user');

		if($query->num_rows() > 0) {
			return $query->result_array();
		} else {
			return array();			
		}
	}
	
	function delete_space($space_id) {
		$this->db->where('space_id',$space_id);
		$this->db->delete('user');
	}
}


?>
